@@ -1,64 +1,45 @@
 <?php
-/**
- * Core functions used all over the scripts.
- * This script is distinct from libraries/common.inc.php because this
- * script is called from /test.
- */
 
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\Plugins\AuthenticationPlugin;
+use PhpMyAdmin\Http\ServerRequest;
 use Symfony\Component\Config\FileLocator;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
-use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\DependencyInjection\Loader\PhpFileLoader;
 
-use const DATE_RFC1123;
-use const E_USER_ERROR;
-use const E_USER_WARNING;
-use const FILTER_VALIDATE_IP;
+use function __;
 use function array_keys;
 use function array_pop;
 use function array_walk_recursive;
 use function chr;
 use function count;
-use function date_default_timezone_get;
-use function date_default_timezone_set;
 use function defined;
 use function explode;
-use function extension_loaded;
 use function filter_var;
 use function function_exists;
 use function getenv;
-use function gettype;
 use function gmdate;
 use function hash_equals;
 use function hash_hmac;
 use function header;
+use function header_remove;
 use function htmlspecialchars;
 use function http_build_query;
-use function implode;
 use function in_array;
-use function ini_get;
-use function ini_set;
 use function intval;
 use function is_array;
-use function is_numeric;
-use function is_scalar;
 use function is_string;
+use function json_decode;
 use function json_encode;
-use function mb_internal_encoding;
 use function mb_strlen;
 use function mb_strpos;
-use function mb_strrpos;
 use function mb_substr;
 use function parse_str;
 use function parse_url;
 use function preg_match;
 use function preg_replace;
-use function session_id;
 use function session_write_close;
 use function sprintf;
 use function str_replace;
@@ -72,170 +53,16 @@ use function unserialize;
 use function urldecode;
 use function vsprintf;
 
+use const DATE_RFC1123;
+use const E_USER_ERROR;
+use const E_USER_WARNING;
+use const FILTER_VALIDATE_IP;
+
 /**
- * Core class
+ * Core functions used all over the scripts.
  */
 class Core
 {
-    /**
-     * checks given $var and returns it if valid, or $default of not valid
-     * given $var is also checked for type being 'similar' as $default
-     * or against any other type if $type is provided
-     *
-     * <code>
-     * // $_REQUEST['db'] not set
-     * echo Core::ifSetOr($_REQUEST['db'], ''); // ''
-     * // $_POST['sql_query'] not set
-     * echo Core::ifSetOr($_POST['sql_query']); // null
-     * // $cfg['EnableFoo'] not set
-     * echo Core::ifSetOr($cfg['EnableFoo'], false, 'boolean'); // false
-     * echo Core::ifSetOr($cfg['EnableFoo']); // null
-     * // $cfg['EnableFoo'] set to 1
-     * echo Core::ifSetOr($cfg['EnableFoo'], false, 'boolean'); // false
-     * echo Core::ifSetOr($cfg['EnableFoo'], false, 'similar'); // 1
-     * echo Core::ifSetOr($cfg['EnableFoo'], false); // 1
-     * // $cfg['EnableFoo'] set to true
-     * echo Core::ifSetOr($cfg['EnableFoo'], false, 'boolean'); // true
-     * </code>
-     *
-     * @see self::isValid()
-     *
-     * @param mixed $var     param to check
-     * @param mixed $default default value
-     * @param mixed $type    var type or array of values to check against $var
-     *
-     * @return mixed $var or $default
-     */
-    public static function ifSetOr(&$var, $default = null, $type = 'similar')
-    {
-        if (! self::isValid($var, $type, $default)) {
-            return $default;
-        }
-
-        return $var;
-    }
-
-    /**
-     * checks given $var against $type or $compare
-     *
-     * $type can be:
-     * - false       : no type checking
-     * - 'scalar'    : whether type of $var is integer, float, string or boolean
-     * - 'numeric'   : whether type of $var is any number representation
-     * - 'length'    : whether type of $var is scalar with a string length > 0
-     * - 'similar'   : whether type of $var is similar to type of $compare
-     * - 'equal'     : whether type of $var is identical to type of $compare
-     * - 'identical' : whether $var is identical to $compare, not only the type!
-     * - or any other valid PHP variable type
-     *
-     * <code>
-     * // $_REQUEST['doit'] = true;
-     * Core::isValid($_REQUEST['doit'], 'identical', 'true'); // false
-     * // $_REQUEST['doit'] = 'true';
-     * Core::isValid($_REQUEST['doit'], 'identical', 'true'); // true
-     * </code>
-     *
-     * NOTE: call-by-reference is used to not get NOTICE on undefined vars,
-     * but the var is not altered inside this function, also after checking a var
-     * this var exists nut is not set, example:
-     * <code>
-     * // $var is not set
-     * isset($var); // false
-     * functionCallByReference($var); // false
-     * isset($var); // true
-     * functionCallByReference($var); // true
-     * </code>
-     *
-     * to avoid this we set this var to null if not isset
-     *
-     * @see https://www.php.net/gettype
-     *
-     * @param mixed $var     variable to check
-     * @param mixed $type    var type or array of valid values to check against $var
-     * @param mixed $compare var to compare with $var
-     *
-     * @return bool whether valid or not
-     *
-     * @todo add some more var types like hex, bin, ...?
-     */
-    public static function isValid(&$var, $type = 'length', $compare = null): bool
-    {
-        if (! isset($var)) {
-            // var is not even set
-            return false;
-        }
-
-        if ($type === false) {
-            // no vartype requested
-            return true;
-        }
-
-        if (is_array($type)) {
-            return in_array($var, $type);
-        }
-
-        // allow some aliases of var types
-        $type = strtolower($type);
-        switch ($type) {
-            case 'identic':
-                $type = 'identical';
-                break;
-            case 'len':
-                $type = 'length';
-                break;
-            case 'bool':
-                $type = 'boolean';
-                break;
-            case 'float':
-                $type = 'double';
-                break;
-            case 'int':
-                $type = 'integer';
-                break;
-            case 'null':
-                $type = 'NULL';
-                break;
-        }
-
-        if ($type === 'identical') {
-            return $var === $compare;
-        }
-
-        // whether we should check against given $compare
-        if ($type === 'similar') {
-            switch (gettype($compare)) {
-                case 'string':
-                case 'boolean':
-                    $type = 'scalar';
-                    break;
-                case 'integer':
-                case 'double':
-                    $type = 'numeric';
-                    break;
-                default:
-                    $type = gettype($compare);
-            }
-        } elseif ($type === 'equal') {
-            $type = gettype($compare);
-        }
-
-        // do the check
-        if ($type === 'length' || $type === 'scalar') {
-            $is_scalar = is_scalar($var);
-            if ($is_scalar && $type === 'length') {
-                return strlen((string) $var) > 0;
-            }
-
-            return $is_scalar;
-        }
-
-        if ($type === 'numeric') {
-            return is_numeric($var);
-        }
-
-        return gettype($var) === $type;
-    }
-
     /**
      * Removes insecure parts in a path; used before include() or
      * require() when a part of the path comes from an insecure source
@@ -275,14 +102,23 @@ class Core
          * Avoid using Response class as config does not have to be loaded yet
          * (this can happen on early fatal error)
          */
-        if (isset($dbi, $GLOBALS['PMA_Config']) && $dbi !== null
-            && $GLOBALS['PMA_Config']->get('is_setup') === false
-            && Response::getInstance()->isAjax()
+        if (
+            isset($dbi, $GLOBALS['config'])
+            && $GLOBALS['config']->get('is_setup') === false
+            && ResponseRenderer::getInstance()->isAjax()
         ) {
-            $response = Response::getInstance();
+            $response = ResponseRenderer::getInstance();
             $response->setRequestStatus(false);
             $response->addJSON('message', Message::error($error_message));
-        } elseif (! empty($_REQUEST['ajax_request'])) {
+
+            if (! defined('TESTSUITE')) {
+                exit;
+            }
+
+            return;
+        }
+
+        if (! empty($_REQUEST['ajax_request'])) {
             // Generate JSON manually
             self::headerJSON();
             echo json_encode(
@@ -291,16 +127,23 @@ class Core
                     'message' => Message::error($error_message)->getDisplay(),
                 ]
             );
-        } else {
-            $error_message = strtr($error_message, ['<br>' => '[br]']);
-            $template = new Template();
 
-            echo $template->render('error/generic', [
-                'lang' => $GLOBALS['lang'] ?? 'en',
-                'dir' => $GLOBALS['text_dir'] ?? 'ltr',
-                'error_message' => Sanitize::sanitizeMessage($error_message),
-            ]);
+            if (! defined('TESTSUITE')) {
+                exit;
+            }
+
+            return;
         }
+
+        $error_message = strtr($error_message, ['<br>' => '[br]']);
+        $template = new Template();
+
+        echo $template->render('error/generic', [
+            'lang' => $GLOBALS['lang'] ?? 'en',
+            'dir' => $GLOBALS['text_dir'] ?? 'ltr',
+            'error_message' => Sanitize::sanitizeMessage($error_message),
+        ]);
+
         if (! defined('TESTSUITE')) {
             exit;
         }
@@ -312,20 +155,16 @@ class Core
      * @param string $target anchor in documentation
      *
      * @return string  the URL
-     *
-     * @access public
      */
     public static function getPHPDocLink(string $target): string
     {
         /* List of PHP documentation translations */
         $php_doc_languages = [
             'pt_BR',
-            'zh',
+            'zh_CN',
             'fr',
             'de',
-            'it',
             'ja',
-            'ro',
             'ru',
             'es',
             'tr',
@@ -333,7 +172,11 @@ class Core
 
         $lang = 'en';
         if (isset($GLOBALS['lang']) && in_array($GLOBALS['lang'], $php_doc_languages)) {
-            $lang = $GLOBALS['lang'];
+            if ($GLOBALS['lang'] === 'zh_CN') {
+                $lang = 'zh';
+            } else {
+                $lang = $GLOBALS['lang'];
+            }
         }
 
         return self::linkURL('https://www.php.net/manual/' . $lang . '/' . $target);
@@ -351,39 +194,28 @@ class Core
         bool $fatal = false,
         string $extra = ''
     ): void {
-        /** @var ErrorHandler $error_handler */
-        global $error_handler;
+        global $errorHandler;
+
+        $message = 'The %s extension is missing. Please check your PHP configuration.';
 
         /* Gettext does not have to be loaded yet here */
         if (function_exists('__')) {
-            $message = __(
-                'The %s extension is missing. Please check your PHP configuration.'
-            );
-        } else {
-            $message
-                = 'The %s extension is missing. Please check your PHP configuration.';
+            $message = __('The %s extension is missing. Please check your PHP configuration.');
         }
+
         $doclink = self::getPHPDocLink('book.' . $extension . '.php');
-        $message = sprintf(
-            $message,
-            '[a@' . $doclink . '@Documentation][em]' . $extension . '[/em][/a]'
-        );
+        $message = sprintf($message, '[a@' . $doclink . '@Documentation][em]' . $extension . '[/em][/a]');
         if ($extra != '') {
             $message .= ' ' . $extra;
         }
+
         if ($fatal) {
             self::fatalError($message);
 
             return;
         }
 
-        $error_handler->addError(
-            $message,
-            E_USER_WARNING,
-            '',
-            0,
-            false
-        );
+        $errorHandler->addError($message, E_USER_WARNING, '', 0, false);
     }
 
     /**
@@ -397,19 +229,13 @@ class Core
     {
         global $dbi;
 
-        $tables = $dbi->tryQuery(
-            'SHOW TABLES FROM ' . Util::backquote($db) . ';',
-            DatabaseInterface::CONNECT_USER,
-            DatabaseInterface::QUERY_STORE
-        );
+        $tables = $dbi->tryQuery('SHOW TABLES FROM ' . Util::backquote($db) . ';');
+
         if ($tables) {
-            $num_tables = $dbi->numRows($tables);
-            $dbi->freeResult($tables);
-        } else {
-            $num_tables = 0;
+            return $tables->numRows();
         }
 
-        return $num_tables;
+        return 0;
     }
 
     /**
@@ -429,12 +255,12 @@ class Core
         $binaryprefixes = [
             'T' => 1099511627776,
             't' => 1099511627776,
-            'G' =>    1073741824,
-            'g' =>    1073741824,
-            'M' =>       1048576,
-            'm' =>       1048576,
-            'K' =>          1024,
-            'k' =>          1024,
+            'G' => 1073741824,
+            'g' => 1073741824,
+            'M' => 1048576,
+            'm' => 1048576,
+            'K' => 1024,
+            'k' => 1024,
         ];
 
         if (preg_match('/^([0-9]+)([KMGT])/i', (string) $size, $matches)) {
@@ -451,14 +277,13 @@ class Core
      * @param string $page      page to check
      * @param array  $allowList allow list to check page against
      * @param bool   $include   whether the page is going to be included
-     *
-     * @return bool whether $page is valid or not (in $allowList or not)
      */
     public static function checkPageValidity(&$page, array $allowList = [], $include = false): bool
     {
         if (empty($allowList)) {
             $allowList = ['index.php'];
         }
+
         if (empty($page)) {
             return false;
         }
@@ -466,6 +291,7 @@ class Core
         if (in_array($page, $allowList)) {
             return true;
         }
+
         if ($include) {
             return false;
         }
@@ -513,9 +339,7 @@ class Core
             return (string) getenv($var_name);
         }
 
-        if (function_exists('apache_getenv')
-            && apache_getenv($var_name, true)
-        ) {
+        if (function_exists('apache_getenv') && apache_getenv($var_name, true)) {
             return (string) apache_getenv($var_name, true);
         }
 
@@ -530,8 +354,8 @@ class Core
      */
     public static function sendHeaderLocation(string $uri, bool $use_refresh = false): void
     {
-        if ($GLOBALS['PMA_Config']->get('PMA_IS_IIS') && mb_strlen($uri) > 600) {
-            Response::getInstance()->disable();
+        if ($GLOBALS['config']->get('PMA_IS_IIS') && mb_strlen($uri) > 600) {
+            ResponseRenderer::getInstance()->disable();
 
             $template = new Template();
             echo $template->render('header_location', ['uri' => $uri]);
@@ -544,26 +368,26 @@ class Core
          * like /phpmyadmin/index.php/ which some web servers happily accept.
          */
         if ($uri[0] === '.') {
-            $uri = $GLOBALS['PMA_Config']->getRootPath() . substr($uri, 2);
+            $uri = $GLOBALS['config']->getRootPath() . substr($uri, 2);
         }
 
-        $response = Response::getInstance();
+        $response = ResponseRenderer::getInstance();
 
         session_write_close();
         if ($response->headersSent()) {
-            trigger_error(
-                'Core::sendHeaderLocation called when headers are already sent!',
-                E_USER_ERROR
-            );
+            trigger_error('Core::sendHeaderLocation called when headers are already sent!', E_USER_ERROR);
         }
+
         // bug #1523784: IE6 does not like 'Refresh: 0', it
         // results in a blank page
         // but we need it when coming from the cookie login panel)
-        if ($GLOBALS['PMA_Config']->get('PMA_IS_IIS') && $use_refresh) {
+        if ($GLOBALS['config']->get('PMA_IS_IIS') && $use_refresh) {
             $response->header('Refresh: 0; ' . $uri);
-        } else {
-            $response->header('Location: ' . $uri);
+
+            return;
         }
+
+        $response->header('Location: ' . $uri);
     }
 
     /**
@@ -574,14 +398,22 @@ class Core
         if (defined('TESTSUITE')) {
             return;
         }
+
         // No caching
-        self::noCacheHeader();
-        // MIME type
-        header('Content-Type: application/json; charset=UTF-8');
-        // Disable content sniffing in browser
-        // This is needed in case we include HTML in JSON, browser might assume it's
-        // html to display
-        header('X-Content-Type-Options: nosniff');
+        $headers = self::getNoCacheHeaders();
+
+        // Media type
+        $headers['Content-Type'] = 'application/json; charset=UTF-8';
+
+        /**
+         * Disable content sniffing in browser.
+         * This is needed in case we include HTML in JSON, browser might assume it's html to display.
+         */
+        $headers['X-Content-Type-Options'] = 'nosniff';
+
+        foreach ($headers as $name => $value) {
+            header(sprintf('%s: %s', $name, $value));
+        }
     }
 
     /**
@@ -592,19 +424,37 @@ class Core
         if (defined('TESTSUITE')) {
             return;
         }
-        // rfc2616 - Section 14.21
-        header('Expires: ' . gmdate(DATE_RFC1123));
-        // HTTP/1.1
-        header(
-            'Cache-Control: no-store, no-cache, must-revalidate,'
-            . '  pre-check=0, post-check=0, max-age=0'
-        );
 
-        header('Pragma: no-cache'); // HTTP/1.0
+        $headers = self::getNoCacheHeaders();
+
+        foreach ($headers as $name => $value) {
+            header(sprintf('%s: %s', $name, $value));
+        }
+    }
+
+    /**
+     * @return array<string, string>
+     */
+    public static function getNoCacheHeaders(): array
+    {
+        $headers = [];
+        $date = (string) gmdate(DATE_RFC1123);
+
+        // rfc2616 - Section 14.21
+        $headers['Expires'] = $date;
+
+        // HTTP/1.1
+        $headers['Cache-Control'] = 'no-store, no-cache, must-revalidate, pre-check=0, post-check=0, max-age=0';
+
+        // HTTP/1.0
+        $headers['Pragma'] = 'no-cache';
+
         // test case: exporting a database into a .gz file with Safari
         // would produce files not having the current time
         // (added this header for Safari but should not harm other browsers)
-        header('Last-Modified: ' . gmdate(DATE_RFC1123));
+        $headers['Last-Modified'] = $date;
+
+        return $headers;
     }
 
     /**
@@ -622,29 +472,35 @@ class Core
         int $length = 0,
         bool $no_cache = true
     ): void {
+        $headers = [];
+
         if ($no_cache) {
-            self::noCacheHeader();
+            $headers = self::getNoCacheHeaders();
         }
+
         /* Replace all possibly dangerous chars in filename */
         $filename = Sanitize::sanitizeFilename($filename);
         if (! empty($filename)) {
-            header('Content-Description: File Transfer');
-            header('Content-Disposition: attachment; filename="' . $filename . '"');
-        }
-        header('Content-Type: ' . $mimetype);
-        // inform the server that compression has been done,
-        // to avoid a double compression (for example with Apache + mod_deflate)
-        $notChromeOrLessThan43 = PMA_USR_BROWSER_AGENT != 'CHROME' // see bug #4942
-            || (PMA_USR_BROWSER_AGENT == 'CHROME' && PMA_USR_BROWSER_VER < 43);
-        if (strpos($mimetype, 'gzip') !== false && $notChromeOrLessThan43) {
-            header('Content-Encoding: gzip');
-        }
-        header('Content-Transfer-Encoding: binary');
-        if ($length <= 0) {
-            return;
+            $headers['Content-Description'] = 'File Transfer';
+            $headers['Content-Disposition'] = 'attachment; filename="' . $filename . '"';
         }
 
-        header('Content-Length: ' . $length);
+        $headers['Content-Type'] = $mimetype;
+
+        // The default output in PMA uses gzip,
+        // so if we want to output uncompressed file, we should reset the encoding.
+        // See PHP bug https://github.com/php/php-src/issues/8218
+        header_remove('Content-Encoding');
+
+        $headers['Content-Transfer-Encoding'] = 'binary';
+
+        if ($length > 0) {
+            $headers['Content-Length'] = (string) $length;
+        }
+
+        foreach ($headers as $name => $value) {
+            header(sprintf('%s: %s', $name, $value));
+        }
     }
 
     /**
@@ -666,6 +522,7 @@ class Core
             if (! isset($value[$key])) {
                 return $default;
             }
+
             $value =& $value[$key];
         }
 
@@ -688,8 +545,10 @@ class Core
             if (! isset($a[$key])) {
                 $a[$key] = [];
             }
+
             $a =& $a[$key];
         }
+
         $a[$last_key] = $value;
     }
 
@@ -714,9 +573,11 @@ class Core
                 $found = false;
                 break;
             }
+
             $depth++;
             $path[$depth] =& $path[$depth - 1][$key];
         }
+
         // if element found, remove it
         if ($found) {
             unset($path[$depth][$keys_last]);
@@ -760,13 +621,11 @@ class Core
         parse_str($arr['query'] ?? '', $vars);
         $query = http_build_query(['url' => $vars['url']]);
 
-        if ($GLOBALS['PMA_Config'] !== null && $GLOBALS['PMA_Config']->get('is_setup')) {
-            $url = '../url.php?' . $query;
-        } else {
-            $url = './url.php?' . $query;
+        if ($GLOBALS['config'] !== null && $GLOBALS['config']->get('is_setup')) {
+            return '../url.php?' . $query;
         }
 
-        return $url;
+        return './url.php?' . $query;
     }
 
     /**
@@ -774,9 +633,6 @@ class Core
      * Use only for URLs of external sites.
      *
      * @param string $url URL of external site.
-     *
-     * @return bool True: if domain of $url is allowed domain,
-     * False: otherwise.
      */
     public static function isAllowedDomain(string $url): bool
     {
@@ -790,6 +646,7 @@ class Core
         if (! isset($arr['host']) || strlen($arr['host']) == 0) {
             return false;
         }
+
         // We do not want these to be present
         $blocked = [
             'user',
@@ -801,6 +658,7 @@ class Core
                 return false;
             }
         }
+
         $domain = $arr['host'];
         $domainAllowList = [
             /* Include current domain */
@@ -864,8 +722,9 @@ class Core
         } else {
             $retval .= Html\Generator::formatSql($query_data);
         }
+
         $retval .= '</div>';
-        $response = Response::getInstance();
+        $response = ResponseRenderer::getInstance();
         $response->addJSON('sql_data', $retval);
     }
 
@@ -873,27 +732,25 @@ class Core
      * recursively check if variable is empty
      *
      * @param mixed $value the variable
-     *
-     * @return bool true if empty
      */
     public static function emptyRecursive($value): bool
     {
-        $empty = true;
         if (is_array($value)) {
+            $empty = true;
             array_walk_recursive(
                 $value,
                 /**
                  * @param mixed $item
                  */
-                static function ($item) use (&$empty) {
+                static function ($item) use (&$empty): void {
                     $empty = $empty && empty($item);
                 }
             );
-        } else {
-            $empty = empty($value);
+
+            return $empty;
         }
 
-        return $empty;
+        return empty($value);
     }
 
     /**
@@ -917,120 +774,10 @@ class Core
         }
     }
 
-    public static function setDatabaseAndTableFromRequest(ContainerInterface $containerBuilder): void
-    {
-        global $db, $table, $url_params;
-
-        $databaseFromRequest = $_POST['db'] ?? $_GET['db'] ?? $_REQUEST['db'] ?? null;
-        $tableFromRequest = $_POST['table'] ?? $_GET['table'] ?? $_REQUEST['table'] ?? null;
-
-        $db = self::isValid($databaseFromRequest) ? $databaseFromRequest : '';
-        $table = self::isValid($tableFromRequest) ? $tableFromRequest : '';
-
-        $url_params['db'] = $db;
-        $url_params['table'] = $table;
-        $containerBuilder->setParameter('db', $db);
-        $containerBuilder->setParameter('table', $table);
-        $containerBuilder->setParameter('url_params', $url_params);
-    }
-
-    /**
-     * PATH_INFO could be compromised if set, so remove it from PHP_SELF
-     * and provide a clean PHP_SELF here
-     */
-    public static function cleanupPathInfo(): void
-    {
-        global $PMA_PHP_SELF;
-
-        $PMA_PHP_SELF = self::getenv('PHP_SELF');
-        if (empty($PMA_PHP_SELF)) {
-            $PMA_PHP_SELF = urldecode(self::getenv('REQUEST_URI'));
-        }
-        $_PATH_INFO = self::getenv('PATH_INFO');
-        if (! empty($_PATH_INFO) && ! empty($PMA_PHP_SELF)) {
-            $question_pos = mb_strpos($PMA_PHP_SELF, '?');
-            if ($question_pos != false) {
-                $PMA_PHP_SELF = mb_substr($PMA_PHP_SELF, 0, $question_pos);
-            }
-            $path_info_pos = mb_strrpos($PMA_PHP_SELF, $_PATH_INFO);
-            if ($path_info_pos !== false) {
-                $path_info_part = mb_substr($PMA_PHP_SELF, $path_info_pos, mb_strlen($_PATH_INFO));
-                if ($path_info_part == $_PATH_INFO) {
-                    $PMA_PHP_SELF = mb_substr($PMA_PHP_SELF, 0, $path_info_pos);
-                }
-            }
-        }
-
-        $path = [];
-        foreach (explode('/', $PMA_PHP_SELF) as $part) {
-            // ignore parts that have no value
-            if (empty($part) || $part === '.') {
-                continue;
-            }
-
-            if ($part !== '..') {
-                // cool, we found a new part
-                $path[] = $part;
-            } elseif (count($path) > 0) {
-                // going back up? sure
-                array_pop($path);
-            }
-            // Here we intentionall ignore case where we go too up
-            // as there is nothing sane to do
-        }
-
-        $PMA_PHP_SELF = htmlspecialchars('/' . implode('/', $path));
-    }
-
-    /**
-     * Checks that required PHP extensions are there.
-     */
-    public static function checkExtensions(): void
-    {
-        /**
-         * Warning about mbstring.
-         */
-        if (! function_exists('mb_detect_encoding')) {
-            self::warnMissingExtension('mbstring');
-        }
-
-        /**
-         * We really need this one!
-         */
-        if (! function_exists('preg_replace')) {
-            self::warnMissingExtension('pcre', true);
-        }
-
-        /**
-         * JSON is required in several places.
-         */
-        if (! function_exists('json_encode')) {
-            self::warnMissingExtension('json', true);
-        }
-
-        /**
-         * ctype is required for Twig.
-         */
-        if (! function_exists('ctype_alpha')) {
-            self::warnMissingExtension('ctype', true);
-        }
-
-        /**
-         * hash is required for cookie authentication.
-         */
-        if (function_exists('hash_hmac')) {
-            return;
-        }
-
-        self::warnMissingExtension('hash', true);
-    }
-
     /**
      * Gets the "true" IP address of the current user
      *
      * @return string|bool the ip of the user
-     *
-     * @access private
      */
     public static function getIp()
     {
@@ -1112,10 +859,6 @@ class Core
      */
     public static function safeUnserialize(string $data)
     {
-        if (! is_string($data)) {
-            return null;
-        }
-
         /* validate serialized data */
         $length = strlen($data);
         $depth = 0;
@@ -1128,6 +871,7 @@ class Core
                     if ($depth <= 0) {
                         return null;
                     }
+
                     $depth--;
                     break;
                 case 's':
@@ -1139,11 +883,13 @@ class Core
                     if ($i === false) {
                         return null;
                     }
+
                     // skip string, quotes and ;
                     $i += 2 + $strlen + 1;
                     if ($data[$i] !== ';') {
                         return null;
                     }
+
                     break;
 
                 case 'b':
@@ -1155,6 +901,7 @@ class Core
                     if ($i === false) {
                         return null;
                     }
+
                     break;
                 case 'a':
                     /* array */
@@ -1163,6 +910,7 @@ class Core
                     if ($i === false) {
                         return null;
                     }
+
                     // remember nesting
                     $depth++;
                     break;
@@ -1173,6 +921,7 @@ class Core
                     if ($i === false) {
                         return null;
                     }
+
                     break;
                 default:
                     /* any other elements are not wanted */
@@ -1188,89 +937,6 @@ class Core
         return unserialize($data);
     }
 
-    /**
-     * Applies changes to PHP configuration.
-     */
-    public static function configure(): void
-    {
-        /**
-         * Set utf-8 encoding for PHP
-         */
-        ini_set('default_charset', 'utf-8');
-        mb_internal_encoding('utf-8');
-
-        /**
-         * Set precision to sane value, with higher values
-         * things behave slightly unexpectedly, for example
-         * round(1.2, 2) returns 1.199999999999999956.
-         */
-        ini_set('precision', '14');
-
-        /**
-         * check timezone setting
-         * this could produce an E_WARNING - but only once,
-         * if not done here it will produce E_WARNING on every date/time function
-         */
-        date_default_timezone_set(@date_default_timezone_get());
-    }
-
-    /**
-     * Check whether PHP configuration matches our needs.
-     */
-    public static function checkConfiguration(): void
-    {
-        /**
-         * As we try to handle charsets by ourself, mbstring overloads just
-         * break it, see bug 1063821.
-         *
-         * We specifically use empty here as we are looking for anything else than
-         * empty value or 0.
-         */
-        if (extension_loaded('mbstring') && ! empty(ini_get('mbstring.func_overload'))) {
-            self::fatalError(
-                __(
-                    'You have enabled mbstring.func_overload in your PHP '
-                    . 'configuration. This option is incompatible with phpMyAdmin '
-                    . 'and might cause some data to be corrupted!'
-                )
-            );
-        }
-
-        /**
-         * The ini_set and ini_get functions can be disabled using
-         * disable_functions but we're relying quite a lot of them.
-         */
-        if (function_exists('ini_get') && function_exists('ini_set')) {
-            return;
-        }
-
-        self::fatalError(
-            __(
-                'The ini_get and/or ini_set functions are disabled in php.ini. '
-                . 'phpMyAdmin requires these functions!'
-            )
-        );
-    }
-
-    /**
-     * Checks request and fails with fatal error if something problematic is found
-     */
-    public static function checkRequest(): void
-    {
-        if (isset($_REQUEST['GLOBALS']) || isset($_FILES['GLOBALS'])) {
-            self::fatalError(__('GLOBALS overwrite attempt'));
-        }
-
-        /**
-         * protect against possible exploits - there is no need to have so much variables
-         */
-        if (count($_REQUEST) <= 1000) {
-            return;
-        }
-
-        self::fatalError(__('possible exploit'));
-    }
-
     /**
      * Sign the sql query using hmac using the session token
      *
@@ -1292,10 +958,8 @@ class Core
      *
      * @param string $sqlQuery  The sql query
      * @param string $signature The Signature to check
-     *
-     * @return bool
      */
-    public static function checkSqlQuerySignature($sqlQuery, $signature)
+    public static function checkSqlQuerySignature($sqlQuery, $signature): bool
     {
         global $cfg;
 
@@ -1305,116 +969,6 @@ class Core
         return hash_equals($hmac, $signature);
     }
 
-    /**
-     * Check whether user supplied token is valid, if not remove any possibly
-     * dangerous stuff from request.
-     *
-     * Check for token mismatch only if the Request method is POST.
-     * GET Requests would never have token and therefore checking
-     * mis-match does not make sense.
-     */
-    public static function checkTokenRequestParam(): void
-    {
-        global $token_mismatch, $token_provided;
-
-        $token_mismatch = true;
-        $token_provided = false;
-
-        if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
-            return;
-        }
-
-        if (self::isValid($_POST['token'])) {
-            $token_provided = true;
-            $token_mismatch = ! @hash_equals($_SESSION[' PMA_token '], $_POST['token']);
-        }
-
-        if (! $token_mismatch) {
-            return;
-        }
-
-        // Warn in case the mismatch is result of failed setting of session cookie
-        if (isset($_POST['set_session']) && $_POST['set_session'] !== session_id()) {
-            trigger_error(
-                __(
-                    'Failed to set session cookie. Maybe you are using '
-                    . 'HTTP instead of HTTPS to access phpMyAdmin.'
-                ),
-                E_USER_ERROR
-            );
-        }
-
-        /**
-         * We don't allow any POST operation parameters if the token is mismatched
-         * or is not provided.
-         */
-        $allowList = ['ajax_request'];
-        Sanitize::removeRequestVars($allowList);
-    }
-
-    public static function setGotoAndBackGlobals(ContainerInterface $container, Config $config): void
-    {
-        global $goto, $back, $url_params;
-
-        // Holds page that should be displayed.
-        $goto = '';
-        $container->setParameter('goto', $goto);
-
-        if (isset($_REQUEST['goto']) && self::checkPageValidity($_REQUEST['goto'])) {
-            $goto = $_REQUEST['goto'];
-            $url_params['goto'] = $goto;
-            $container->setParameter('goto', $goto);
-            $container->setParameter('url_params', $url_params);
-        } else {
-            if ($config->issetCookie('goto')) {
-                $config->removeCookie('goto');
-            }
-            unset($_REQUEST['goto'], $_GET['goto'], $_POST['goto']);
-        }
-
-        if (isset($_REQUEST['back']) && self::checkPageValidity($_REQUEST['back'])) {
-            // Returning page.
-            $back = $_REQUEST['back'];
-            $container->setParameter('back', $back);
-        } else {
-            if ($config->issetCookie('back')) {
-                $config->removeCookie('back');
-            }
-            unset($_REQUEST['back'], $_GET['back'], $_POST['back']);
-        }
-    }
-
-    public static function connectToDatabaseServer(DatabaseInterface $dbi, AuthenticationPlugin $auth): void
-    {
-        global $cfg;
-
-        /**
-         * Try to connect MySQL with the control user profile (will be used to get the privileges list for the current
-         * user but the true user link must be open after this one so it would be default one for all the scripts).
-         */
-        $controlLink = false;
-        if ($cfg['Server']['controluser'] !== '') {
-            $controlLink = $dbi->connect(DatabaseInterface::CONNECT_CONTROL);
-        }
-
-        // Connects to the server (validates user's login)
-        $userLink = $dbi->connect(DatabaseInterface::CONNECT_USER);
-
-        if ($userLink === false) {
-            $auth->showFailure('mysql-denied');
-        }
-
-        if ($controlLink) {
-            return;
-        }
-
-        /**
-         * Open separate connection for control queries, this is needed to avoid problems with table locking used in
-         * main connection and phpMyAdmin issuing queries to configuration storage, which is not locked by that time.
-         */
-        $dbi->connect(DatabaseInterface::CONNECT_USER, null, DatabaseInterface::CONNECT_CONTROL);
-    }
-
     /**
      * Get the container builder
      */
@@ -1426,4 +980,64 @@ class Core
 
         return $containerBuilder;
     }
+
+    public static function populateRequestWithEncryptedQueryParams(ServerRequest $request): ServerRequest
+    {
+        $queryParams = $request->getQueryParams();
+        $parsedBody = $request->getParsedBody();
+
+        unset($_GET['eq'], $_POST['eq'], $_REQUEST['eq']);
+
+        if (! isset($queryParams['eq']) && (! is_array($parsedBody) || ! isset($parsedBody['eq']))) {
+            return $request;
+        }
+
+        $encryptedQuery = '';
+        if (
+            is_array($parsedBody)
+            && isset($parsedBody['eq'])
+            && is_string($parsedBody['eq'])
+            && $parsedBody['eq'] !== ''
+        ) {
+            $encryptedQuery = $parsedBody['eq'];
+            unset($parsedBody['eq'], $queryParams['eq']);
+        } elseif (isset($queryParams['eq']) && is_string($queryParams['eq']) && $queryParams['eq'] !== '') {
+            $encryptedQuery = $queryParams['eq'];
+            unset($queryParams['eq']);
+        }
+
+        $decryptedQuery = null;
+        if ($encryptedQuery !== '') {
+            $decryptedQuery = Url::decryptQuery($encryptedQuery);
+        }
+
+        if ($decryptedQuery === null) {
+            $request = $request->withQueryParams($queryParams);
+            if (is_array($parsedBody)) {
+                $request = $request->withParsedBody($parsedBody);
+            }
+
+            return $request;
+        }
+
+        $urlQueryParams = (array) json_decode($decryptedQuery);
+        foreach ($urlQueryParams as $urlQueryParamKey => $urlQueryParamValue) {
+            if (is_array($parsedBody)) {
+                $parsedBody[$urlQueryParamKey] = $urlQueryParamValue;
+                $_POST[$urlQueryParamKey] = $urlQueryParamValue;
+            } else {
+                $queryParams[$urlQueryParamKey] = $urlQueryParamValue;
+                $_GET[$urlQueryParamKey] = $urlQueryParamValue;
+            }
+
+            $_REQUEST[$urlQueryParamKey] = $urlQueryParamValue;
+        }
+
+        $request = $request->withQueryParams($queryParams);
+        if (is_array($parsedBody)) {
+            $request = $request->withParsedBody($parsedBody);
+        }
+
+        return $request;
+    }
 }
