@@ -7,16 +7,15 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Gis;
 
+use PhpMyAdmin\Image\ImageWrapper;
 use TCPDF;
+
 use function count;
 use function explode;
 use function hexdec;
-use function imagecolorallocate;
-use function imageline;
-use function imagestring;
 use function json_encode;
-use function mb_strlen;
 use function mb_substr;
+use function round;
 use function trim;
 
 /**
@@ -29,8 +28,6 @@ class GisMultiLineString extends GisGeometry
 
     /**
      * A private constructor; prevents direct creation of object.
-     *
-     * @access private
      */
     private function __construct()
     {
@@ -40,8 +37,6 @@ class GisMultiLineString extends GisGeometry
      * Returns the singleton.
      *
      * @return GisMultiLineString the singleton
-     *
-     * @access public
      */
     public static function singleton()
     {
@@ -58,20 +53,13 @@ class GisMultiLineString extends GisGeometry
      * @param string $spatial spatial data of a row
      *
      * @return array an array containing the min, max values for x and y coordinates
-     *
-     * @access public
      */
     public function scaleRow($spatial)
     {
         $min_max = [];
 
         // Trim to remove leading 'MULTILINESTRING((' and trailing '))'
-        $multilinestirng
-            = mb_substr(
-                $spatial,
-                17,
-                mb_strlen($spatial) - 19
-            );
+        $multilinestirng = mb_substr($spatial, 17, -2);
         // Separate each linestring
         $linestirngs = explode('),(', $multilinestirng);
 
@@ -89,33 +77,25 @@ class GisMultiLineString extends GisGeometry
      * @param string|null $label      Label for the GIS POLYGON object
      * @param string      $line_color Color for the GIS POLYGON object
      * @param array       $scale_data Array containing data related to scaling
-     * @param resource    $image      Image object
-     *
-     * @return resource the modified image object
-     *
-     * @access public
      */
     public function prepareRowAsPng(
         $spatial,
         ?string $label,
         $line_color,
         array $scale_data,
-        $image
-    ) {
+        ImageWrapper $image
+    ): ImageWrapper {
         // allocate colors
-        $black = imagecolorallocate($image, 0, 0, 0);
-        $red = hexdec(mb_substr($line_color, 1, 2));
-        $green = hexdec(mb_substr($line_color, 3, 2));
-        $blue = hexdec(mb_substr($line_color, 4, 2));
-        $color = imagecolorallocate($image, $red, $green, $blue);
+        $black = $image->colorAllocate(0, 0, 0);
+        $red = (int) hexdec(mb_substr($line_color, 1, 2));
+        $green = (int) hexdec(mb_substr($line_color, 3, 2));
+        $blue = (int) hexdec(mb_substr($line_color, 4, 2));
+        $color = $image->colorAllocate($red, $green, $blue);
+
+        $label = trim($label ?? '');
 
         // Trim to remove leading 'MULTILINESTRING((' and trailing '))'
-        $multilinestirng
-            = mb_substr(
-                $spatial,
-                17,
-                mb_strlen($spatial) - 19
-            );
+        $multilinestirng = mb_substr($spatial, 17, -2);
         // Separate each linestring
         $linestirngs = explode('),(', $multilinestirng);
 
@@ -123,33 +103,32 @@ class GisMultiLineString extends GisGeometry
         foreach ($linestirngs as $linestring) {
             $points_arr = $this->extractPoints($linestring, $scale_data);
             foreach ($points_arr as $point) {
-                if (! isset($temp_point)) {
-                    $temp_point = $point;
-                } else {
+                if (isset($temp_point)) {
                     // draw line section
-                    imageline(
-                        $image,
-                        (int) $temp_point[0],
-                        (int) $temp_point[1],
-                        (int) $point[0],
-                        (int) $point[1],
+                    $image->line(
+                        (int) round($temp_point[0]),
+                        (int) round($temp_point[1]),
+                        (int) round($point[0]),
+                        (int) round($point[1]),
                         $color
                     );
-                    $temp_point = $point;
                 }
+
+                $temp_point = $point;
             }
+
             unset($temp_point);
             // print label if applicable
-            if (isset($label) && trim($label) != '' && $first_line) {
-                imagestring(
-                    $image,
+            if ($label !== '' && $first_line) {
+                $image->string(
                     1,
-                    $points_arr[1][0],
-                    $points_arr[1][1],
-                    trim($label),
+                    (int) round($points_arr[1][0]),
+                    (int) round($points_arr[1][1]),
+                    $label,
                     $black
                 );
             }
+
             $first_line = false;
         }
 
@@ -166,8 +145,6 @@ class GisMultiLineString extends GisGeometry
      * @param TCPDF       $pdf        TCPDF instance
      *
      * @return TCPDF the modified TCPDF instance
-     *
-     * @access public
      */
     public function prepareRowAsPdf($spatial, ?string $label, $line_color, array $scale_data, $pdf)
     {
@@ -184,13 +161,10 @@ class GisMultiLineString extends GisGeometry
             ],
         ];
 
+        $label = trim($label ?? '');
+
         // Trim to remove leading 'MULTILINESTRING((' and trailing '))'
-        $multilinestirng
-            = mb_substr(
-                $spatial,
-                17,
-                mb_strlen($spatial) - 19
-            );
+        $multilinestirng = mb_substr($spatial, 17, -2);
         // Separate each linestring
         $linestirngs = explode('),(', $multilinestirng);
 
@@ -198,27 +172,22 @@ class GisMultiLineString extends GisGeometry
         foreach ($linestirngs as $linestring) {
             $points_arr = $this->extractPoints($linestring, $scale_data);
             foreach ($points_arr as $point) {
-                if (! isset($temp_point)) {
-                    $temp_point = $point;
-                } else {
+                if (isset($temp_point)) {
                     // draw line section
-                    $pdf->Line(
-                        $temp_point[0],
-                        $temp_point[1],
-                        $point[0],
-                        $point[1],
-                        $line
-                    );
-                    $temp_point = $point;
+                    $pdf->Line($temp_point[0], $temp_point[1], $point[0], $point[1], $line);
                 }
+
+                $temp_point = $point;
             }
+
             unset($temp_point);
             // print label
-            if (isset($label) && trim($label) != '' && $first_line) {
-                $pdf->SetXY($points_arr[1][0], $points_arr[1][1]);
-                $pdf->SetFontSize(5);
-                $pdf->Cell(0, 0, trim($label));
+            if ($label !== '' && $first_line) {
+                $pdf->setXY($points_arr[1][0], $points_arr[1][1]);
+                $pdf->setFontSize(5);
+                $pdf->Cell(0, 0, $label);
             }
+
             $first_line = false;
         }
 
@@ -234,26 +203,19 @@ class GisMultiLineString extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code related to a row in the GIS dataset
-     *
-     * @access public
      */
     public function prepareRowAsSvg($spatial, $label, $line_color, array $scale_data)
     {
         $line_options = [
-            'name'         => $label,
-            'class'        => 'linestring vector',
-            'fill'         => 'none',
-            'stroke'       => $line_color,
+            'name' => $label,
+            'class' => 'linestring vector',
+            'fill' => 'none',
+            'stroke' => $line_color,
             'stroke-width' => 2,
         ];
 
         // Trim to remove leading 'MULTILINESTRING((' and trailing '))'
-        $multilinestirng
-            = mb_substr(
-                $spatial,
-                17,
-                mb_strlen($spatial) - 19
-            );
+        $multilinestirng = mb_substr($spatial, 17, -2);
         // Separate each linestring
         $linestirngs = explode('),(', $multilinestirng);
 
@@ -265,11 +227,13 @@ class GisMultiLineString extends GisGeometry
             foreach ($points_arr as $point) {
                 $row .= $point[0] . ',' . $point[1] . ' ';
             }
+
             $row .= '"';
             $line_options['id'] = $label . $this->getRandomId();
             foreach ($line_options as $option => $val) {
                 $row .= ' ' . $option . '="' . trim((string) $val) . '"';
             }
+
             $row .= '/>';
         }
 
@@ -287,37 +251,31 @@ class GisMultiLineString extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string JavaScript related to a row in the GIS dataset
-     *
-     * @access public
      */
-    public function prepareRowAsOl($spatial, $srid, $label, $line_color, array $scale_data)
+    public function prepareRowAsOl($spatial, int $srid, $label, $line_color, array $scale_data)
     {
         $stroke_style = [
             'color' => $line_color,
             'width' => 2,
         ];
 
-        $row =  'var style = new ol.style.Style({'
+        $row = 'var style = new ol.style.Style({'
             . 'stroke: new ol.style.Stroke(' . json_encode($stroke_style) . ')';
-        if ($label) {
-            $text_style = ['text' => $label];
+        if (trim($label) !== '') {
+            $text_style = ['text' => trim($label)];
             $row .= ', text: new ol.style.Text(' . json_encode($text_style) . ')';
         }
 
         $row .= '});';
 
-        if ($srid == 0) {
+        if ($srid === 0) {
             $srid = 4326;
         }
+
         $row .= $this->getBoundsForOl($srid, $scale_data);
 
         // Trim to remove leading 'MULTILINESTRING((' and trailing '))'
-        $multilinestirng
-            = mb_substr(
-                $spatial,
-                17,
-                mb_strlen($spatial) - 19
-            );
+        $multilinestirng = mb_substr($spatial, 17, -2);
         // Separate each linestring
         $linestirngs = explode('),(', $multilinestirng);
 
@@ -331,13 +289,11 @@ class GisMultiLineString extends GisGeometry
     /**
      * Generate the WKT with the set of parameters passed by the GIS editor.
      *
-     * @param array  $gis_data GIS data
-     * @param int    $index    Index into the parameter object
-     * @param string $empty    Value for empty points
+     * @param array       $gis_data GIS data
+     * @param int         $index    Index into the parameter object
+     * @param string|null $empty    Value for empty points
      *
      * @return string WKT with the set of parameters passed by the GIS editor
-     *
-     * @access public
      */
     public function generateWkt(array $gis_data, $index, $empty = '')
     {
@@ -354,6 +310,7 @@ class GisMultiLineString extends GisGeometry
             if ($no_of_points < 2) {
                 $no_of_points = 2;
             }
+
             $wkt .= '(';
             for ($j = 0; $j < $no_of_points; $j++) {
                 $wkt .= (isset($data_row[$i][$j]['x'])
@@ -363,20 +320,12 @@ class GisMultiLineString extends GisGeometry
                         && trim((string) $data_row[$i][$j]['y']) != ''
                         ? $data_row[$i][$j]['y'] : $empty) . ',';
             }
-            $wkt
-                = mb_substr(
-                    $wkt,
-                    0,
-                    mb_strlen($wkt) - 1
-                );
+
+            $wkt = mb_substr($wkt, 0, -1);
             $wkt .= '),';
         }
-        $wkt
-            = mb_substr(
-                $wkt,
-                0,
-                mb_strlen($wkt) - 1
-            );
+
+        $wkt = mb_substr($wkt, 0, -1);
 
         return $wkt . ')';
     }
@@ -387,8 +336,6 @@ class GisMultiLineString extends GisGeometry
      * @param array $row_data GIS data
      *
      * @return string the WKT for the data from ESRI shape files
-     *
-     * @access public
      */
     public function getShape(array $row_data)
     {
@@ -398,20 +345,12 @@ class GisMultiLineString extends GisGeometry
             foreach ($row_data['parts'][$i]['points'] as $point) {
                 $wkt .= $point['x'] . ' ' . $point['y'] . ',';
             }
-            $wkt
-                = mb_substr(
-                    $wkt,
-                    0,
-                    mb_strlen($wkt) - 1
-                );
+
+            $wkt = mb_substr($wkt, 0, -1);
             $wkt .= '),';
         }
-        $wkt
-            = mb_substr(
-                $wkt,
-                0,
-                mb_strlen($wkt) - 1
-            );
+
+        $wkt = mb_substr($wkt, 0, -1);
 
         return $wkt . ')';
     }
@@ -423,8 +362,6 @@ class GisMultiLineString extends GisGeometry
      * @param int    $index Index of the geometry
      *
      * @return array params for the GIS data editor from the value of the GIS column
-     *
-     * @access public
      */
     public function generateParams($value, $index = -1)
     {
@@ -440,12 +377,7 @@ class GisMultiLineString extends GisGeometry
         }
 
         // Trim to remove leading 'MULTILINESTRING((' and trailing '))'
-        $multilinestirng
-            = mb_substr(
-                $wkt,
-                17,
-                mb_strlen($wkt) - 19
-            );
+        $multilinestirng = mb_substr($wkt, 17, -2);
         // Separate each linestring
         $linestirngs = explode('),(', $multilinestirng);
         $params[$index]['MULTILINESTRING']['no_of_lines'] = count($linestirngs);
@@ -459,6 +391,7 @@ class GisMultiLineString extends GisGeometry
                 $params[$index]['MULTILINESTRING'][$j][$i]['x'] = $points_arr[$i][0];
                 $params[$index]['MULTILINESTRING'][$j][$i]['y'] = $points_arr[$i][1];
             }
+
             $j++;
         }
 
