@@ -7,20 +7,18 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Gis;
 
+use PhpMyAdmin\Image\ImageWrapper;
 use TCPDF;
+
 use function array_merge;
-use function array_push;
 use function array_slice;
 use function count;
 use function explode;
 use function hexdec;
-use function imagecolorallocate;
-use function imagefilledpolygon;
-use function imagestring;
 use function json_encode;
-use function mb_strlen;
-use function mb_strpos;
 use function mb_substr;
+use function round;
+use function str_contains;
 use function trim;
 
 /**
@@ -33,8 +31,6 @@ class GisMultiPolygon extends GisGeometry
 
     /**
      * A private constructor; prevents direct creation of object.
-     *
-     * @access private
      */
     private function __construct()
     {
@@ -44,8 +40,6 @@ class GisMultiPolygon extends GisGeometry
      * Returns the singleton.
      *
      * @return GisMultiPolygon the singleton
-     *
-     * @access public
      */
     public static function singleton()
     {
@@ -62,32 +56,26 @@ class GisMultiPolygon extends GisGeometry
      * @param string $spatial spatial data of a row
      *
      * @return array an array containing the min, max values for x and y coordinates
-     *
-     * @access public
      */
     public function scaleRow($spatial)
     {
         $min_max = [];
 
         // Trim to remove leading 'MULTIPOLYGON(((' and trailing ')))'
-        $multipolygon
-            = mb_substr(
-                $spatial,
-                15,
-                mb_strlen($spatial) - 18
-            );
+        $multipolygon = mb_substr($spatial, 15, -3);
         // Separate each polygon
         $polygons = explode(')),((', $multipolygon);
 
         foreach ($polygons as $polygon) {
             // If the polygon doesn't have an inner ring, use polygon itself
-            if (mb_strpos($polygon, '),(') === false) {
+            if (! str_contains($polygon, '),(')) {
                 $ring = $polygon;
             } else {
                 // Separate outer ring and use it to determine min-max
                 $parts = explode('),(', $polygon);
                 $ring = $parts[0];
             }
+
             $min_max = $this->setMinMax($ring, $min_max);
         }
 
@@ -101,41 +89,32 @@ class GisMultiPolygon extends GisGeometry
      * @param string|null $label      Label for the GIS POLYGON object
      * @param string      $fill_color Color for the GIS POLYGON object
      * @param array       $scale_data Array containing data related to scaling
-     * @param resource    $image      Image object
-     *
-     * @return resource the modified image object
-     *
-     * @access public
      */
     public function prepareRowAsPng(
         $spatial,
         ?string $label,
         $fill_color,
         array $scale_data,
-        $image
-    ) {
+        ImageWrapper $image
+    ): ImageWrapper {
         // allocate colors
-        $black = imagecolorallocate($image, 0, 0, 0);
-        $red = hexdec(mb_substr($fill_color, 1, 2));
-        $green = hexdec(mb_substr($fill_color, 3, 2));
-        $blue = hexdec(mb_substr($fill_color, 4, 2));
-        $color = imagecolorallocate($image, $red, $green, $blue);
+        $black = $image->colorAllocate(0, 0, 0);
+        $red = (int) hexdec(mb_substr($fill_color, 1, 2));
+        $green = (int) hexdec(mb_substr($fill_color, 3, 2));
+        $blue = (int) hexdec(mb_substr($fill_color, 4, 2));
+        $color = $image->colorAllocate($red, $green, $blue);
+
+        $label = trim($label ?? '');
 
         // Trim to remove leading 'MULTIPOLYGON(((' and trailing ')))'
-        $multipolygon
-            = mb_substr(
-                $spatial,
-                15,
-                mb_strlen($spatial) - 18
-            );
+        $multipolygon = mb_substr($spatial, 15, -3);
         // Separate each polygon
         $polygons = explode(')),((', $multipolygon);
 
         $first_poly = true;
-        $points_arr = [];
         foreach ($polygons as $polygon) {
             // If the polygon doesn't have an inner polygon
-            if (mb_strpos($polygon, '),(') === false) {
+            if (! str_contains($polygon, '),(')) {
                 $points_arr = $this->extractPoints($polygon, $scale_data, true);
             } else {
                 // Separate outer and inner polygons
@@ -152,25 +131,27 @@ class GisMultiPolygon extends GisGeometry
                     );
                 }
             }
+
             // draw polygon
-            imagefilledpolygon($image, $points_arr, count($points_arr) / 2, $color);
+            $image->filledPolygon($points_arr, $color);
             // mark label point if applicable
-            if (isset($label) && trim($label) != '' && $first_poly) {
+            if ($label !== '' && $first_poly) {
                 $label_point = [
                     $points_arr[2],
                     $points_arr[3],
                 ];
             }
+
             $first_poly = false;
         }
+
         // print label if applicable
         if (isset($label_point)) {
-            imagestring(
-                $image,
+            $image->string(
                 1,
-                $points_arr[2],
-                $points_arr[3],
-                trim((string) $label),
+                (int) round($label_point[0]),
+                (int) round($label_point[1]),
+                $label,
                 $black
             );
         }
@@ -188,8 +169,6 @@ class GisMultiPolygon extends GisGeometry
      * @param TCPDF       $pdf        TCPDF instance
      *
      * @return TCPDF the modified TCPDF instance
-     *
-     * @access public
      */
     public function prepareRowAsPdf($spatial, ?string $label, $fill_color, array $scale_data, $pdf)
     {
@@ -203,20 +182,17 @@ class GisMultiPolygon extends GisGeometry
             $blue,
         ];
 
+        $label = trim($label ?? '');
+
         // Trim to remove leading 'MULTIPOLYGON(((' and trailing ')))'
-        $multipolygon
-            = mb_substr(
-                $spatial,
-                15,
-                mb_strlen($spatial) - 18
-            );
+        $multipolygon = mb_substr($spatial, 15, -3);
         // Separate each polygon
         $polygons = explode(')),((', $multipolygon);
 
         $first_poly = true;
         foreach ($polygons as $polygon) {
             // If the polygon doesn't have an inner polygon
-            if (mb_strpos($polygon, '),(') === false) {
+            if (! str_contains($polygon, '),(')) {
                 $points_arr = $this->extractPoints($polygon, $scale_data, true);
             } else {
                 // Separate outer and inner polygons
@@ -233,23 +209,25 @@ class GisMultiPolygon extends GisGeometry
                     );
                 }
             }
+
             // draw polygon
             $pdf->Polygon($points_arr, 'F*', [], $color, true);
             // mark label point if applicable
-            if (isset($label) && trim($label) != '' && $first_poly) {
+            if ($label !== '' && $first_poly) {
                 $label_point = [
                     $points_arr[2],
                     $points_arr[3],
                 ];
             }
+
             $first_poly = false;
         }
 
         // print label if applicable
         if (isset($label_point)) {
-            $pdf->SetXY($label_point[0], $label_point[1]);
-            $pdf->SetFontSize(5);
-            $pdf->Cell(0, 0, trim((string) $label));
+            $pdf->setXY($label_point[0], $label_point[1]);
+            $pdf->setFontSize(5);
+            $pdf->Cell(0, 0, $label);
         }
 
         return $pdf;
@@ -264,30 +242,23 @@ class GisMultiPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code related to a row in the GIS dataset
-     *
-     * @access public
      */
     public function prepareRowAsSvg($spatial, $label, $fill_color, array $scale_data)
     {
         $polygon_options = [
-            'name'         => $label,
-            'class'        => 'multipolygon vector',
-            'stroke'       => 'black',
+            'name' => $label,
+            'class' => 'multipolygon vector',
+            'stroke' => 'black',
             'stroke-width' => 0.5,
-            'fill'         => $fill_color,
-            'fill-rule'    => 'evenodd',
+            'fill' => $fill_color,
+            'fill-rule' => 'evenodd',
             'fill-opacity' => 0.8,
         ];
 
         $row = '';
 
         // Trim to remove leading 'MULTIPOLYGON(((' and trailing ')))'
-        $multipolygon
-            = mb_substr(
-                $spatial,
-                15,
-                mb_strlen($spatial) - 18
-            );
+        $multipolygon = mb_substr($spatial, 15, -3);
         // Separate each polygon
         $polygons = explode(')),((', $multipolygon);
 
@@ -295,7 +266,7 @@ class GisMultiPolygon extends GisGeometry
             $row .= '<path d="';
 
             // If the polygon doesn't have an inner polygon
-            if (mb_strpos($polygon, '),(') === false) {
+            if (! str_contains($polygon, '),(')) {
                 $row .= $this->drawPath($polygon, $scale_data);
             } else {
                 // Separate outer and inner polygons
@@ -309,11 +280,13 @@ class GisMultiPolygon extends GisGeometry
                     $row .= $this->drawPath($inner_poly, $scale_data);
                 }
             }
+
             $polygon_options['id'] = $label . $this->getRandomId();
             $row .= '"';
             foreach ($polygon_options as $option => $val) {
                 $row .= ' ' . $option . '="' . trim((string) $val) . '"';
             }
+
             $row .= '/>';
         }
 
@@ -331,41 +304,34 @@ class GisMultiPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string JavaScript related to a row in the GIS dataset
-     *
-     * @access public
      */
-    public function prepareRowAsOl($spatial, $srid, $label, $fill_color, array $scale_data)
+    public function prepareRowAsOl($spatial, int $srid, $label, $fill_color, array $scale_data)
     {
-        $fill_opacity = 0.8;
-        array_push($fill_color, $fill_opacity);
+        $fill_color[] = 0.8;
         $fill_style = ['color' => $fill_color];
         $stroke_style = [
             'color' => [0,0,0],
             'width' => 0.5,
         ];
-        $row =  'var style = new ol.style.Style({'
+        $row = 'var style = new ol.style.Style({'
             . 'fill: new ol.style.Fill(' . json_encode($fill_style) . '),'
             . 'stroke: new ol.style.Stroke(' . json_encode($stroke_style) . ')';
 
-        if ($label) {
-            $text_style = ['text' => $label];
+        if (trim($label) !== '') {
+            $text_style = ['text' => trim($label)];
             $row .= ',text: new ol.style.Text(' . json_encode($text_style) . ')';
         }
 
         $row .= '});';
 
-        if ($srid == 0) {
+        if ($srid === 0) {
             $srid = 4326;
         }
+
         $row .= $this->getBoundsForOl($srid, $scale_data);
 
         // Trim to remove leading 'MULTIPOLYGON(((' and trailing ')))'
-        $multipolygon
-            = mb_substr(
-                $spatial,
-                15,
-                mb_strlen($spatial) - 18
-            );
+        $multipolygon = mb_substr($spatial, 15, -3);
         // Separate each polygon
         $polygons = explode(')),((', $multipolygon);
 
@@ -383,8 +349,6 @@ class GisMultiPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code to draw the ring
-     *
-     * @access private
      */
     private function drawPath($polygon, array $scale_data)
     {
@@ -395,6 +359,7 @@ class GisMultiPolygon extends GisGeometry
         foreach ($other_points as $point) {
             $row .= ' L ' . $point[0] . ', ' . $point[1];
         }
+
         $row .= ' Z ';
 
         return $row;
@@ -403,13 +368,11 @@ class GisMultiPolygon extends GisGeometry
     /**
      * Generate the WKT with the set of parameters passed by the GIS editor.
      *
-     * @param array  $gis_data GIS data
-     * @param int    $index    Index into the parameter object
-     * @param string $empty    Value for empty points
+     * @param array       $gis_data GIS data
+     * @param int         $index    Index into the parameter object
+     * @param string|null $empty    Value for empty points
      *
      * @return string WKT with the set of parameters passed by the GIS editor
-     *
-     * @access public
      */
     public function generateWkt(array $gis_data, $index, $empty = '')
     {
@@ -426,12 +389,14 @@ class GisMultiPolygon extends GisGeometry
             if ($no_of_lines < 1) {
                 $no_of_lines = 1;
             }
+
             $wkt .= '(';
             for ($i = 0; $i < $no_of_lines; $i++) {
                 $no_of_points = $data_row[$k][$i]['no_of_points'] ?? 4;
                 if ($no_of_points < 4) {
                     $no_of_points = 4;
                 }
+
                 $wkt .= '(';
                 for ($j = 0; $j < $no_of_points; $j++) {
                     $wkt .= (isset($data_row[$k][$i][$j]['x'])
@@ -441,28 +406,16 @@ class GisMultiPolygon extends GisGeometry
                             && trim((string) $data_row[$k][$i][$j]['y']) != ''
                             ? $data_row[$k][$i][$j]['y'] : $empty) . ',';
                 }
-                $wkt
-                    = mb_substr(
-                        $wkt,
-                        0,
-                        mb_strlen($wkt) - 1
-                    );
+
+                $wkt = mb_substr($wkt, 0, -1);
                 $wkt .= '),';
             }
-            $wkt
-                = mb_substr(
-                    $wkt,
-                    0,
-                    mb_strlen($wkt) - 1
-                );
+
+            $wkt = mb_substr($wkt, 0, -1);
             $wkt .= '),';
         }
-        $wkt
-            = mb_substr(
-                $wkt,
-                0,
-                mb_strlen($wkt) - 1
-            );
+
+        $wkt = mb_substr($wkt, 0, -1);
 
         return $wkt . ')';
     }
@@ -473,8 +426,6 @@ class GisMultiPolygon extends GisGeometry
      * @param array $row_data GIS data
      *
      * @return string the WKT for the data from ESRI shape files
-     *
-     * @access public
      */
     public function getShape(array $row_data)
     {
@@ -482,8 +433,7 @@ class GisMultiPolygon extends GisGeometry
         // If it's an inner ring get a point on the surface which can be used to
         // correctly classify inner rings to their respective outer rings.
         foreach ($row_data['parts'] as $i => $ring) {
-            $row_data['parts'][$i]['isOuter']
-                = GisPolygon::isOuterRing($ring['points']);
+            $row_data['parts'][$i]['isOuter'] = GisPolygon::isOuterRing($ring['points']);
         }
 
         // Find points on surface for inner rings
@@ -492,8 +442,7 @@ class GisMultiPolygon extends GisGeometry
                 continue;
             }
 
-            $row_data['parts'][$i]['pointOnSurface']
-                = GisPolygon::getPointOnSurface($ring['points']);
+            $row_data['parts'][$i]['pointOnSurface'] = GisPolygon::getPointOnSurface($ring['points']);
         }
 
         // Classify inner rings to their respective outer rings.
@@ -501,6 +450,7 @@ class GisMultiPolygon extends GisGeometry
             if ($ring1['isOuter']) {
                 continue;
             }
+
             foreach ($row_data['parts'] as $k => $ring2) {
                 if (! $ring2['isOuter']) {
                     continue;
@@ -508,17 +458,14 @@ class GisMultiPolygon extends GisGeometry
 
                 // If the pointOnSurface of the inner ring
                 // is also inside the outer ring
-                if (! GisPolygon::isPointInsidePolygon(
-                    $ring1['pointOnSurface'],
-                    $ring2['points']
-                )
-                ) {
+                if (! GisPolygon::isPointInsidePolygon($ring1['pointOnSurface'], $ring2['points'])) {
                     continue;
                 }
 
                 if (! isset($ring2['inner'])) {
                     $row_data['parts'][$k]['inner'] = [];
                 }
+
                 $row_data['parts'][$k]['inner'][] = $j;
             }
         }
@@ -536,12 +483,8 @@ class GisMultiPolygon extends GisGeometry
             foreach ($ring['points'] as $point) {
                 $wkt .= $point['x'] . ' ' . $point['y'] . ',';
             }
-            $wkt
-                = mb_substr(
-                    $wkt,
-                    0,
-                    mb_strlen($wkt) - 1
-                );
+
+            $wkt = mb_substr($wkt, 0, -1);
             $wkt .= ')'; // end of outer ring
 
             // inner rings if any
@@ -551,24 +494,16 @@ class GisMultiPolygon extends GisGeometry
                     foreach ($row_data['parts'][$j]['points'] as $innerPoint) {
                         $wkt .= $innerPoint['x'] . ' ' . $innerPoint['y'] . ',';
                     }
-                    $wkt
-                        = mb_substr(
-                            $wkt,
-                            0,
-                            mb_strlen($wkt) - 1
-                        );
-                    $wkt .= ')';  // end of inner ring
+
+                    $wkt = mb_substr($wkt, 0, -1);
+                    $wkt .= ')'; // end of inner ring
                 }
             }
 
             $wkt .= '),'; // end of polygon
         }
-        $wkt
-            = mb_substr(
-                $wkt,
-                0,
-                mb_strlen($wkt) - 1
-            );
+
+        $wkt = mb_substr($wkt, 0, -1);
 
         return $wkt . ')';
     }
@@ -580,8 +515,6 @@ class GisMultiPolygon extends GisGeometry
      * @param int    $index Index of the geometry
      *
      * @return array params for the GIS data editor from the value of the GIS column
-     *
-     * @access public
      */
     public function generateParams($value, $index = -1)
     {
@@ -597,12 +530,7 @@ class GisMultiPolygon extends GisGeometry
         }
 
         // Trim to remove leading 'MULTIPOLYGON(((' and trailing ')))'
-        $multipolygon
-            = mb_substr(
-                $wkt,
-                15,
-                mb_strlen($wkt) - 18
-            );
+        $multipolygon = mb_substr($wkt, 15, -3);
         // Separate each polygon
         $polygons = explode(')),((', $multipolygon);
 
@@ -612,7 +540,7 @@ class GisMultiPolygon extends GisGeometry
         $k = 0;
         foreach ($polygons as $polygon) {
             // If the polygon doesn't have an inner polygon
-            if (mb_strpos($polygon, '),(') === false) {
+            if (! str_contains($polygon, '),(')) {
                 $param_row[$k]['no_of_lines'] = 1;
                 $points_arr = $this->extractPoints($polygon, null);
                 $no_of_points = count($points_arr);
@@ -634,9 +562,11 @@ class GisMultiPolygon extends GisGeometry
                         $param_row[$k][$j][$i]['x'] = $points_arr[$i][0];
                         $param_row[$k][$j][$i]['y'] = $points_arr[$i][1];
                     }
+
                     $j++;
                 }
             }
+
             $k++;
         }
 
