@@ -293,8 +293,6 @@ class ExportOdt extends ExportPlugin
                         . '</table:table-cell>';
                 } elseif (
                     $fieldsMeta[$j]->isNumeric
-                    && ! $fieldsMeta[$j]->isMappedTypeTimestamp
-                    && ! $fieldsMeta[$j]->isBlob
                 ) {
                     $GLOBALS['odt_buffer'] .= '<table:table-cell office:value-type="float"'
                         . ' office:value="' . $row[$j] . '" >'
@@ -322,13 +320,20 @@ class ExportOdt extends ExportPlugin
     /**
      * Outputs result raw query in ODT format
      *
-     * @param string $errorUrl the url to go back in case of error
-     * @param string $sqlQuery the rawquery to output
-     * @param string $crlf     the end of line sequence
+     * @param string      $errorUrl the url to go back in case of error
+     * @param string|null $db       the database where the query is executed
+     * @param string      $sqlQuery the rawquery to output
+     * @param string      $crlf     the end of line sequence
      */
-    public function exportRawQuery(string $errorUrl, string $sqlQuery, string $crlf): bool
+    public function exportRawQuery(string $errorUrl, ?string $db, string $sqlQuery, string $crlf): bool
     {
-        return $this->exportData('', '', $crlf, $errorUrl, $sqlQuery);
+        global $dbi;
+
+        if ($db !== null) {
+            $dbi->selectDb($db);
+        }
+
+        return $this->exportData($db ?? '', '', $crlf, $errorUrl, $sqlQuery);
     }
 
     /**
