@@ -1,28 +1,31 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * PDF schema handling
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Schema\Pdf;
 
 use PhpMyAdmin\Pdf as PdfLib;
 use PhpMyAdmin\Plugins\Schema\ExportRelationSchema;
-use PhpMyAdmin\Relation;
 use PhpMyAdmin\Transformations;
 use PhpMyAdmin\Util;
 
-/**
- * Skip the plugin if TCPDF is not available.
- */
-if (! class_exists('TCPDF')) {
-    $GLOBALS['skip_import'] = true;
-    return;
-}
+use function __;
+use function ceil;
+use function getcwd;
+use function in_array;
+use function intval;
+use function max;
+use function min;
+use function rsort;
+use function sort;
+use function sprintf;
+use function str_replace;
+use function strtotime;
 
+// phpcs:disable PSR1.Files.SideEffects
 /**
  * block attempts to directly run this script
  */
@@ -30,6 +33,8 @@ if (getcwd() == __DIR__) {
     die('Attack stopped');
 }
 
+// phpcs:enable
+
 /**
  * Pdf Relation Schema Class
  *
@@ -39,50 +44,65 @@ if (getcwd() == __DIR__) {
  * This class inherits ExportRelationSchema class has common functionality added
  * to this class
  *
- * @name Pdf_Relation_Schema
- * @package PhpMyAdmin
+ * @property Pdf $diagram
  */
 class PdfRelationSchema extends ExportRelationSchema
 {
-    /**
-     * Defines properties
-     */
-    private $_showGrid;
-    private $_withDoc;
-    private $_tableOrder;
+    /** @var bool */
+    private $showGrid = false;
 
-    /**
-     * @var TableStatsPdf[]
-     */
-    private $_tables = [];
-    private $_ff = PdfLib::PMA_PDF_FONT;
-    private $_xMax = 0;
-    private $_yMax = 0;
-    private $_scale;
-    private $_xMin = 100000;
-    private $_yMin = 100000;
-    private $_topMargin = 10;
-    private $_bottomMargin = 10;
-    private $_leftMargin = 10;
-    private $_rightMargin = 10;
-    private $_tablewidth;
+    /** @var bool */
+    private $withDoc = false;
 
-    /**
-     * @var RelationStatsPdf[]
-     */
+    /** @var string */
+    private $tableOrder = '';
+
+    /** @var TableStatsPdf[] */
+    private $tables = [];
+
+    /** @var string */
+    private $ff = PdfLib::PMA_PDF_FONT;
+
+    /** @var int|float */
+    private $xMax = 0;
+
+    /** @var int|float */
+    private $yMax = 0;
+
+    /** @var float|int */
+    private $scale;
+
+    /** @var int|float */
+    private $xMin = 100000;
+
+    /** @var int|float */
+    private $yMin = 100000;
+
+    /** @var int */
+    private $topMargin = 10;
+
+    /** @var int */
+    private $bottomMargin = 10;
+
+    /** @var int */
+    private $leftMargin = 10;
+
+    /** @var int */
+    private $rightMargin = 10;
+
+    /** @var int */
+    private $tablewidth = 0;
+
+    /** @var RelationStatsPdf[] */
     protected $relations = [];
 
-    /**
-     * @var Transformations
-     */
+    /** @var Transformations */
     private $transformations;
 
     /**
-     * The "PdfRelationSchema" constructor
+     * @see Schema\Pdf
      *
      * @param string $db database name
-     *
-     * @see PMA_Schema_PDF
      */
     public function __construct($db)
     {
@@ -95,8 +115,8 @@ class PdfRelationSchema extends ExportRelationSchema
         $this->setAllTablesSameWidth(isset($_REQUEST['pdf_all_tables_same_width']));
         $this->setWithDataDictionary(isset($_REQUEST['pdf_with_doc']));
         $this->setTableOrder($_REQUEST['pdf_table_order']);
-        $this->setOrientation($_REQUEST['pdf_orientation']);
-        $this->setPaper($_REQUEST['pdf_paper']);
+        $this->setOrientation((string) $_REQUEST['pdf_orientation']);
+        $this->setPaper((string) $_REQUEST['pdf_paper']);
 
         // Initializes a new document
         parent::__construct(
@@ -106,11 +126,11 @@ class PdfRelationSchema extends ExportRelationSchema
                 'mm',
                 $this->paper,
                 $this->pageNumber,
-                $this->_withDoc,
+                $this->withDoc,
                 $db
             )
         );
-        $this->diagram->SetTitle(
+        $this->diagram->setTitle(
             sprintf(
                 __('Schema of the %s database'),
                 $this->db
@@ -118,81 +138,78 @@ class PdfRelationSchema extends ExportRelationSchema
         );
         $this->diagram->setCMargin(0);
         $this->diagram->Open();
-        $this->diagram->SetAutoPageBreak('auto');
+        $this->diagram->setAutoPageBreak(true);
         $this->diagram->setOffline($this->offline);
 
         $alltables = $this->getTablesFromRequest();
-        if ($this->getTableOrder() == 'name_asc') {
+        if ($this->getTableOrder() === 'name_asc') {
             sort($alltables);
-        } elseif ($this->getTableOrder() == 'name_desc') {
+        } elseif ($this->getTableOrder() === 'name_desc') {
             rsort($alltables);
         }
 
-        if ($this->_withDoc) {
-            $this->diagram->SetAutoPageBreak('auto', 15);
+        if ($this->withDoc) {
+            $this->diagram->setAutoPageBreak(true, 15);
             $this->diagram->setCMargin(1);
             $this->dataDictionaryDoc($alltables);
-            $this->diagram->SetAutoPageBreak('auto');
+            $this->diagram->setAutoPageBreak(true);
             $this->diagram->setCMargin(0);
         }
 
         $this->diagram->AddPage();
 
-        if ($this->_withDoc) {
-            $this->diagram->SetLink($this->diagram->PMA_links['RT']['-'], -1);
+        if ($this->withDoc) {
+            $this->diagram->setLink($this->diagram->customLinks['RT']['-'], -1);
             $this->diagram->Bookmark(__('Relational schema'));
             $this->diagram->setAlias('{00}', $this->diagram->PageNo());
-            $this->_topMargin = 28;
-            $this->_bottomMargin = 28;
+            $this->topMargin = 28;
+            $this->bottomMargin = 28;
         }
 
         /* snip */
         foreach ($alltables as $table) {
-            if (! isset($this->_tables[$table])) {
-                $this->_tables[$table] = new TableStatsPdf(
+            if (! isset($this->tables[$table])) {
+                $this->tables[$table] = new TableStatsPdf(
                     $this->diagram,
                     $this->db,
                     $table,
                     null,
                     $this->pageNumber,
-                    $this->_tablewidth,
+                    $this->tablewidth,
                     $this->showKeys,
                     $this->tableDimension,
                     $this->offline
                 );
             }
+
             if ($this->sameWide) {
-                $this->_tables[$table]->width = $this->_tablewidth;
+                $this->tables[$table]->width = $this->tablewidth;
             }
-            $this->_setMinMax($this->_tables[$table]);
+
+            $this->setMinMax($this->tables[$table]);
         }
 
         // Defines the scale factor
-        $innerWidth = $this->diagram->getPageWidth() - $this->_rightMargin
-            - $this->_leftMargin;
-        $innerHeight = $this->diagram->getPageHeight() - $this->_topMargin
-            - $this->_bottomMargin;
-        $this->_scale = ceil(
+        $innerWidth = $this->diagram->getPageWidth() - $this->rightMargin
+            - $this->leftMargin;
+        $innerHeight = $this->diagram->getPageHeight() - $this->topMargin
+            - $this->bottomMargin;
+        $this->scale = ceil(
             max(
-                ($this->_xMax - $this->_xMin) / $innerWidth,
-                ($this->_yMax - $this->_yMin) / $innerHeight
+                ($this->xMax - $this->xMin) / $innerWidth,
+                ($this->yMax - $this->yMin) / $innerHeight
             ) * 100
         ) / 100;
 
-        $this->diagram->setScale(
-            $this->_scale,
-            $this->_xMin,
-            $this->_yMin,
-            $this->_leftMargin,
-            $this->_topMargin
-        );
+        $this->diagram->setScale($this->scale, $this->xMin, $this->yMin, $this->leftMargin, $this->topMargin);
         // Builds and save the PDF document
         $this->diagram->setLineWidthScale(0.1);
 
-        if ($this->_showGrid) {
-            $this->diagram->SetFontSize(10);
-            $this->_strokeGrid();
+        if ($this->showGrid) {
+            $this->diagram->setFontSize(10);
+            $this->strokeGrid();
         }
+
         $this->diagram->setFontSizeScale(14);
         // previous logic was checking master tables and foreign tables
         // but I think that looping on every table of the pdf page as a master
@@ -210,15 +227,11 @@ class PdfRelationSchema extends ExportRelationSchema
                 // by the user
                 // (do not use array_search() because we would have to
                 // to do a === false and this is not PHP3 compatible)
-                if ($master_field != 'foreign_keys_data') {
+                if ($master_field !== 'foreign_keys_data') {
                     if (in_array($rel['foreign_table'], $alltables)) {
-                        $this->_addRelation(
-                            $one_table,
-                            $master_field,
-                            $rel['foreign_table'],
-                            $rel['foreign_field']
-                        );
+                        $this->addRelation($one_table, $master_field, $rel['foreign_table'], $rel['foreign_field']);
                     }
+
                     continue;
                 }
 
@@ -228,7 +241,7 @@ class PdfRelationSchema extends ExportRelationSchema
                     }
 
                     foreach ($one_key['index_list'] as $index => $one_field) {
-                        $this->_addRelation(
+                        $this->addRelation(
                             $one_table,
                             $one_field,
                             $one_key['ref_table_name'],
@@ -236,69 +249,60 @@ class PdfRelationSchema extends ExportRelationSchema
                         );
                     }
                 }
-            } // end while
-        } // end while
+            }
+        }
 
         if ($seen_a_relation) {
-            $this->_drawRelations();
+            $this->drawRelations();
         }
-        $this->_drawTables();
+
+        $this->drawTables();
     }
 
     /**
      * Set Show Grid
      *
-     * @param boolean $value show grid of the document or not
-     *
-     * @return void
+     * @param bool $value show grid of the document or not
      */
-    public function setShowGrid($value)
+    public function setShowGrid($value): void
     {
-        $this->_showGrid = $value;
+        $this->showGrid = $value;
     }
 
     /**
      * Returns whether to show grid
-     *
-     * @return boolean whether to show grid
      */
-    public function isShowGrid()
+    public function isShowGrid(): bool
     {
-        return $this->_showGrid;
+        return $this->showGrid;
     }
 
     /**
      * Set Data Dictionary
      *
-     * @param boolean $value show selected database data dictionary or not
-     *
-     * @return void
+     * @param bool $value show selected database data dictionary or not
      */
-    public function setWithDataDictionary($value)
+    public function setWithDataDictionary($value): void
     {
-        $this->_withDoc = $value;
+        $this->withDoc = $value;
     }
 
     /**
      * Return whether to show selected database data dictionary or not
-     *
-     * @return boolean whether to show selected database data dictionary or not
      */
-    public function isWithDataDictionary()
+    public function isWithDataDictionary(): bool
     {
-        return $this->_withDoc;
+        return $this->withDoc;
     }
 
     /**
      * Sets the order of the table in data dictionary
      *
      * @param string $value table order
-     *
-     * @return void
      */
-    public function setTableOrder($value)
+    public function setTableOrder($value): void
     {
-        $this->_tableOrder = $value;
+        $this->tableOrder = $value;
     }
 
     /**
@@ -308,15 +312,13 @@ class PdfRelationSchema extends ExportRelationSchema
      */
     public function getTableOrder()
     {
-        return $this->_tableOrder;
+        return $this->tableOrder;
     }
 
     /**
      * Output Pdf Document for download
-     *
-     * @return void
      */
-    public function showOutput()
+    public function showOutput(): void
     {
         $this->diagram->download($this->getFileName('.pdf'));
     }
@@ -325,66 +327,64 @@ class PdfRelationSchema extends ExportRelationSchema
      * Sets X and Y minimum and maximum for a table cell
      *
      * @param TableStatsPdf $table The table name of which sets XY co-ordinates
-     *
-     * @return void
      */
-    private function _setMinMax($table)
+    private function setMinMax($table): void
     {
-        $this->_xMax = max($this->_xMax, $table->x + $table->width);
-        $this->_yMax = max($this->_yMax, $table->y + $table->height);
-        $this->_xMin = min($this->_xMin, $table->x);
-        $this->_yMin = min($this->_yMin, $table->y);
+        $this->xMax = max($this->xMax, $table->x + $table->width);
+        $this->yMax = max($this->yMax, $table->y + $table->height);
+        $this->xMin = min($this->xMin, $table->x);
+        $this->yMin = min($this->yMin, $table->y);
     }
 
     /**
      * Defines relation objects
      *
+     * @see setMinMax
+     *
      * @param string $masterTable  The master table name
      * @param string $masterField  The relation field in the master table
      * @param string $foreignTable The foreign table name
      * @param string $foreignField The relation field in the foreign table
-     *
-     * @return void
-     *
-     * @see _setMinMax
      */
-    private function _addRelation(
+    private function addRelation(
         $masterTable,
         $masterField,
         $foreignTable,
         $foreignField
-    ) {
-        if (! isset($this->_tables[$masterTable])) {
-            $this->_tables[$masterTable] = new TableStatsPdf(
+    ): void {
+        if (! isset($this->tables[$masterTable])) {
+            $this->tables[$masterTable] = new TableStatsPdf(
                 $this->diagram,
                 $this->db,
                 $masterTable,
                 null,
                 $this->pageNumber,
-                $this->_tablewidth,
+                $this->tablewidth,
                 $this->showKeys,
                 $this->tableDimension
             );
-            $this->_setMinMax($this->_tables[$masterTable]);
+            $this->setMinMax($this->tables[$masterTable]);
         }
-        if (! isset($this->_tables[$foreignTable])) {
-            $this->_tables[$foreignTable] = new TableStatsPdf(
+
+        if (! isset($this->tables[$foreignTable])) {
+            $this->tables[$foreignTable] = new TableStatsPdf(
                 $this->diagram,
                 $this->db,
                 $foreignTable,
                 null,
                 $this->pageNumber,
-                $this->_tablewidth,
+                $this->tablewidth,
                 $this->showKeys,
                 $this->tableDimension
             );
-            $this->_setMinMax($this->_tables[$foreignTable]);
+            $this->setMinMax($this->tables[$foreignTable]);
         }
+
         $this->relations[] = new RelationStatsPdf(
             $this->diagram,
-            $this->_tables[$masterTable],
+            $this->tables[$masterTable],
             $masterField,
-            $this->_tables[$foreignTable],
+            $this->tables[$foreignTable],
             $foreignField
         );
     }
@@ -392,16 +392,14 @@ class PdfRelationSchema extends ExportRelationSchema
     /**
      * Draws the grid
      *
-     * @return void
-     *
      * @see PMA_Schema_PDF
      */
-    private function _strokeGrid()
+    private function strokeGrid(): void
     {
         $gridSize = 10;
         $labelHeight = 4;
         $labelWidth = 5;
-        if ($this->_withDoc) {
+        if ($this->withDoc) {
             $topSpace = 6;
             $bottomSpace = 15;
         } else {
@@ -409,8 +407,8 @@ class PdfRelationSchema extends ExportRelationSchema
             $bottomSpace = 0;
         }
 
-        $this->diagram->SetMargins(0, 0);
-        $this->diagram->SetDrawColor(200, 200, 200);
+        $this->diagram->setMargins(0, 0);
+        $this->diagram->setDrawColor(200, 200, 200);
         // Draws horizontal lines
         $innerHeight = $this->diagram->getPageHeight() - $topSpace - $bottomSpace;
         for ($l = 0, $size = intval($innerHeight / $gridSize); $l <= $size; $l++) {
@@ -421,18 +419,19 @@ class PdfRelationSchema extends ExportRelationSchema
                 $l * $gridSize + $topSpace
             );
             // Avoid duplicates
-            if ($l > 0
-                && $l <= intval(($innerHeight - $labelHeight) / $gridSize)
-            ) {
-                $this->diagram->SetXY(0, $l * $gridSize + $topSpace);
-                $label = (string) sprintf(
-                    '%.0f',
-                    ($l * $gridSize + $topSpace - $this->_topMargin)
-                    * $this->_scale + $this->_yMin
-                );
-                $this->diagram->Cell($labelWidth, $labelHeight, ' ' . $label);
-            } // end if
-        } // end for
+            if ($l <= 0 || $l > intval(($innerHeight - $labelHeight) / $gridSize)) {
+                continue;
+            }
+
+            $this->diagram->setXY(0, $l * $gridSize + $topSpace);
+            $label = (string) sprintf(
+                '%.0f',
+                ($l * $gridSize + $topSpace - $this->topMargin)
+                * $this->scale + $this->yMin
+            );
+            $this->diagram->Cell($labelWidth, $labelHeight, ' ' . $label);
+        }
+
         // Draws vertical lines
         for ($j = 0, $size = intval($this->diagram->getPageWidth() / $gridSize); $j <= $size; $j++) {
             $this->diagram->line(
@@ -441,11 +440,8 @@ class PdfRelationSchema extends ExportRelationSchema
                 $j * $gridSize,
                 $this->diagram->getPageHeight() - $bottomSpace
             );
-            $this->diagram->SetXY($j * $gridSize, $topSpace);
-            $label = (string) sprintf(
-                '%.0f',
-                ($j * $gridSize - $this->_leftMargin) * $this->_scale + $this->_xMin
-            );
+            $this->diagram->setXY($j * $gridSize, $topSpace);
+            $label = (string) sprintf('%.0f', ($j * $gridSize - $this->leftMargin) * $this->scale + $this->xMin);
             $this->diagram->Cell($labelWidth, $labelHeight, $label);
         }
     }
@@ -453,11 +449,9 @@ class PdfRelationSchema extends ExportRelationSchema
     /**
      * Draws relation arrows
      *
-     * @return void
-     *
      * @see Relation_Stats_Pdf::relationdraw()
      */
-    private function _drawRelations()
+    private function drawRelations(): void
     {
         $i = 0;
         foreach ($this->relations as $relation) {
@@ -469,14 +463,12 @@ class PdfRelationSchema extends ExportRelationSchema
     /**
      * Draws tables
      *
-     * @return void
-     *
-     * @see Table_Stats_Pdf::tableDraw()
+     * @see TableStatsPdf::tableDraw()
      */
-    private function _drawTables()
+    private function drawTables(): void
     {
-        foreach ($this->_tables as $table) {
-            $table->tableDraw(null, $this->_withDoc, $this->showColor);
+        foreach ($this->tables as $table) {
+            $table->tableDraw(null, $this->withDoc, $this->showColor);
         }
     }
 
@@ -484,32 +476,31 @@ class PdfRelationSchema extends ExportRelationSchema
      * Generates data dictionary pages.
      *
      * @param array $alltables Tables to document.
-     *
-     * @return void
      */
-    public function dataDictionaryDoc(array $alltables)
+    public function dataDictionaryDoc(array $alltables): void
     {
-         // TOC
+        global $dbi;
+
+        // TOC
         $this->diagram->AddPage($this->orientation);
         $this->diagram->Cell(0, 9, __('Table of contents'), 1, 0, 'C');
         $this->diagram->Ln(15);
         $i = 1;
         foreach ($alltables as $table) {
-            $this->diagram->PMA_links['doc'][$table]['-']
-                = $this->diagram->AddLink();
-            $this->diagram->SetX(10);
+            $this->diagram->customLinks['doc'][$table]['-'] = $this->diagram->AddLink();
+            $this->diagram->setX(10);
             // $this->diagram->Ln(1);
             $this->diagram->Cell(
                 0,
                 6,
-                __('Page number:') . ' {' . sprintf("%02d", $i) . '}',
+                __('Page number:') . ' {' . sprintf('%02d', $i) . '}',
                 0,
                 0,
                 'R',
-                0,
-                $this->diagram->PMA_links['doc'][$table]['-']
+                false,
+                $this->diagram->customLinks['doc'][$table]['-']
             );
-            $this->diagram->SetX(10);
+            $this->diagram->setX(10);
             $this->diagram->Cell(
                 0,
                 6,
@@ -517,25 +508,22 @@ class PdfRelationSchema extends ExportRelationSchema
                 0,
                 1,
                 'L',
-                0,
-                $this->diagram->PMA_links['doc'][$table]['-']
+                false,
+                $this->diagram->customLinks['doc'][$table]['-']
             );
             // $this->diagram->Ln(1);
-            $fields = $GLOBALS['dbi']->getColumns($this->db, $table);
+            $fields = $dbi->getColumns($this->db, $table);
             foreach ($fields as $row) {
-                $this->diagram->SetX(20);
+                $this->diagram->setX(20);
                 $field_name = $row['Field'];
-                $this->diagram->PMA_links['doc'][$table][$field_name]
-                    = $this->diagram->AddLink();
-                //$this->diagram->Cell(
-                //    0, 6, $field_name, 0, 1,
-                //    'L', 0, $this->diagram->PMA_links['doc'][$table][$field_name]
-                //);
+                $this->diagram->customLinks['doc'][$table][$field_name] = $this->diagram->AddLink();
             }
+
             $i++;
         }
-        $this->diagram->PMA_links['RT']['-'] = $this->diagram->AddLink();
-        $this->diagram->SetX(10);
+
+        $this->diagram->customLinks['RT']['-'] = $this->diagram->AddLink();
+        $this->diagram->setX(10);
         $this->diagram->Cell(
             0,
             6,
@@ -543,10 +531,10 @@ class PdfRelationSchema extends ExportRelationSchema
             0,
             0,
             'R',
-            0,
-            $this->diagram->PMA_links['RT']['-']
+            false,
+            $this->diagram->customLinks['RT']['-']
         );
-        $this->diagram->SetX(10);
+        $this->diagram->setX(10);
         $this->diagram->Cell(
             0,
             6,
@@ -554,26 +542,22 @@ class PdfRelationSchema extends ExportRelationSchema
             0,
             1,
             'L',
-            0,
-            $this->diagram->PMA_links['RT']['-']
+            false,
+            $this->diagram->customLinks['RT']['-']
         );
         $z = 0;
         foreach ($alltables as $table) {
             $z++;
-            $this->diagram->SetAutoPageBreak(true, 15);
+            $this->diagram->setAutoPageBreak(true, 15);
             $this->diagram->AddPage($this->orientation);
             $this->diagram->Bookmark($table);
             $this->diagram->setAlias(
-                '{' . sprintf("%02d", $z) . '}',
+                '{' . sprintf('%02d', $z) . '}',
                 $this->diagram->PageNo()
             );
-            $this->diagram->PMA_links['RT'][$table]['-']
-                = $this->diagram->AddLink();
-            $this->diagram->SetLink(
-                $this->diagram->PMA_links['doc'][$table]['-'],
-                -1
-            );
-            $this->diagram->SetFont($this->_ff, 'B', 18);
+            $this->diagram->customLinks['RT'][$table]['-'] = $this->diagram->AddLink();
+            $this->diagram->setLink($this->diagram->customLinks['doc'][$table]['-'], -1);
+            $this->diagram->setFont($this->ff, 'B', 18);
             $this->diagram->Cell(
                 0,
                 8,
@@ -581,37 +565,35 @@ class PdfRelationSchema extends ExportRelationSchema
                 1,
                 1,
                 'C',
-                0,
-                $this->diagram->PMA_links['RT'][$table]['-']
+                false,
+                $this->diagram->customLinks['RT'][$table]['-']
             );
-            $this->diagram->SetFont($this->_ff, '', 8);
+            $this->diagram->setFont($this->ff, '', 8);
             $this->diagram->Ln();
 
-            $cfgRelation = $this->relation->getRelationsParam();
+            $relationParameters = $this->relation->getRelationParameters();
             $comments = $this->relation->getComments($this->db, $table);
-            if ($cfgRelation['mimework']) {
+            if ($relationParameters->browserTransformationFeature !== null) {
                 $mime_map = $this->transformations->getMime($this->db, $table, true);
             }
 
             /**
              * Gets table information
              */
-            $showtable = $GLOBALS['dbi']->getTable($this->db, $table)
+            $showtable = $dbi->getTable($this->db, $table)
                 ->getStatusInfo();
-            $show_comment = isset($showtable['Comment'])
-                ? $showtable['Comment']
-                : '';
-            $create_time  = isset($showtable['Create_time'])
+            $show_comment = $showtable['Comment'] ?? '';
+            $create_time = isset($showtable['Create_time'])
                 ? Util::localisedDate(
                     strtotime($showtable['Create_time'])
                 )
                 : '';
-            $update_time  = isset($showtable['Update_time'])
+            $update_time = isset($showtable['Update_time'])
                 ? Util::localisedDate(
                     strtotime($showtable['Update_time'])
                 )
                 : '';
-            $check_time   = isset($showtable['Check_time'])
+            $check_time = isset($showtable['Check_time'])
                 ? Util::localisedDate(
                     strtotime($showtable['Check_time'])
                 )
@@ -620,7 +602,7 @@ class PdfRelationSchema extends ExportRelationSchema
             /**
              * Gets fields properties
              */
-            $columns = $GLOBALS['dbi']->getColumns($this->db, $table);
+            $columns = $dbi->getColumns($this->db, $table);
 
             // Find which tables are related with the current one and write it in
             // an array
@@ -680,8 +662,8 @@ class PdfRelationSchema extends ExportRelationSchema
                 $this->diagram->Ln();
             }
 
-            $this->diagram->SetFont($this->_ff, 'B');
-            if (isset($this->orientation) && $this->orientation == 'L') {
+            $this->diagram->setFont($this->ff, 'B');
+            if (isset($this->orientation) && $this->orientation === 'L') {
                 $this->diagram->Cell(25, 8, __('Column'), 1, 0, 'C');
                 $this->diagram->Cell(20, 8, __('Type'), 1, 0, 'C');
                 $this->diagram->Cell(20, 8, __('Attributes'), 1, 0, 'C');
@@ -690,7 +672,7 @@ class PdfRelationSchema extends ExportRelationSchema
                 $this->diagram->Cell(25, 8, __('Extra'), 1, 0, 'C');
                 $this->diagram->Cell(45, 8, __('Links to'), 1, 0, 'C');
 
-                if ($this->paper == 'A4') {
+                if ($this->paper === 'A4') {
                     $comments_width = 67;
                 } else {
                     // this is really intended for 'letter'
@@ -699,6 +681,7 @@ class PdfRelationSchema extends ExportRelationSchema
                      */
                     $comments_width = 50;
                 }
+
                 $this->diagram->Cell($comments_width, 8, __('Comments'), 1, 0, 'C');
                 $this->diagram->Cell(45, 8, 'MIME', 1, 1, 'C');
                 $this->diagram->setWidths(
@@ -726,27 +709,24 @@ class PdfRelationSchema extends ExportRelationSchema
                 $this->diagram->Cell(30, 8, 'MIME', 1, 1, 'C');
                 $this->diagram->setWidths([20, 20, 20, 10, 15, 15, 30, 30, 30]);
             }
-            $this->diagram->SetFont($this->_ff, '');
+
+            $this->diagram->setFont($this->ff, '');
 
             foreach ($columns as $row) {
-                $extracted_columnspec
-                    = Util::extractColumnSpec($row['Type']);
-                $type                = $extracted_columnspec['print_type'];
-                $attribute           = $extracted_columnspec['attribute'];
+                $extracted_columnspec = Util::extractColumnSpec($row['Type']);
+                $type = $extracted_columnspec['print_type'];
+                $attribute = $extracted_columnspec['attribute'];
                 if (! isset($row['Default'])) {
-                    if ($row['Null'] != '' && $row['Null'] != 'NO') {
+                    if ($row['Null'] != '' && $row['Null'] !== 'NO') {
                         $row['Default'] = 'NULL';
                     }
                 }
+
                 $field_name = $row['Field'];
                 // $this->diagram->Ln();
-                $this->diagram->PMA_links['RT'][$table][$field_name]
-                    = $this->diagram->AddLink();
+                $this->diagram->customLinks['RT'][$table][$field_name] = $this->diagram->AddLink();
                 $this->diagram->Bookmark($field_name, 1, -1);
-                $this->diagram->SetLink(
-                    $this->diagram->PMA_links['doc'][$table][$field_name],
-                    -1
-                );
+                $this->diagram->setLink($this->diagram->customLinks['doc'][$table][$field_name], -1);
                 $foreigner = $this->relation->searchColumnInForeigners($res_rel, $field_name);
 
                 $linksTo = '';
@@ -755,6 +735,7 @@ class PdfRelationSchema extends ExportRelationSchema
                     if ($foreigner['foreign_db'] != $this->db) {
                         $linksTo .= $foreigner['foreign_db'] . '.';
                     }
+
                     $linksTo .= $foreigner['foreign_table']
                         . '.' . $foreigner['foreign_field'];
 
@@ -768,31 +749,33 @@ class PdfRelationSchema extends ExportRelationSchema
                     $field_name,
                     $type,
                     $attribute,
-                    ($row['Null'] == '' || $row['Null'] == 'NO')
+                    $row['Null'] == '' || $row['Null'] === 'NO'
                         ? __('No')
                         : __('Yes'),
-                    isset($row['Default']) ? $row['Default'] : '',
+                    $row['Default'] ?? '',
                     $row['Extra'],
                     $linksTo,
-                    isset($comments[$field_name])
-                        ? $comments[$field_name]
-                        : '',
-                    isset($mime_map) && isset($mime_map[$field_name])
+                    $comments[$field_name] ?? '',
+                    isset($mime_map, $mime_map[$field_name])
                         ? str_replace('_', '/', $mime_map[$field_name]['mimetype'])
                         : '',
                 ];
                 $links = [];
-                $links[0] = $this->diagram->PMA_links['RT'][$table][$field_name];
-                if ($foreigner
-                    && isset($this->diagram->PMA_links['doc'][$foreigner['foreign_table']][$foreigner['foreign_field']])
+                $links[0] = $this->diagram->customLinks['RT'][$table][$field_name];
+                if (
+                    $foreigner
+                    && isset(
+                        $this->diagram->customLinks['doc'][$foreigner['foreign_table']][$foreigner['foreign_field']]
+                    )
                 ) {
-                    $links[6] = $this->diagram->PMA_links['doc'][$foreigner['foreign_table']][$foreigner['foreign_field']];
-                } else {
-                    unset($links[6]);
+                    $foreignTable = $this->diagram->customLinks['doc'][$foreigner['foreign_table']];
+                    $links[6] = $foreignTable[$foreigner['foreign_field']];
                 }
+
                 $this->diagram->row($diagram_row, $links);
-            } // end foreach
-            $this->diagram->SetFont($this->_ff, '', 14);
-        } //end each
+            }
+
+            $this->diagram->setFont($this->ff, '', 14);
+        }
     }
 }
