@@ -9,9 +9,9 @@ use FastRoute\Dispatcher;
 use FastRoute\Dispatcher\GroupCountBased as DispatcherGroupCountBased;
 use FastRoute\RouteCollector;
 use FastRoute\RouteParser\Std as RouteParserStd;
+use PhpMyAdmin\Controllers\HomeController;
 use PhpMyAdmin\Http\ServerRequest;
 use Psr\Container\ContainerInterface;
-use RuntimeException;
 
 use function __;
 use function file_exists;
@@ -28,6 +28,7 @@ use function var_export;
 
 use const CACHE_DIR;
 use const E_USER_WARNING;
+use const ROOT_PATH;
 
 /**
  * Class used to warm up the routing cache and manage routing.
@@ -73,13 +74,11 @@ class Routing
         // If skip cache is enabled, do not try to read the file
         // If no cache skipping then read it and use it
         if (! $skipCache && file_exists(self::ROUTES_CACHE_FILE)) {
-            /** @psalm-suppress MissingFile, UnresolvableInclude */
+            /** @psalm-suppress MissingFile, UnresolvableInclude, MixedAssignment */
             $dispatchData = require self::ROUTES_CACHE_FILE;
-            if (! is_array($dispatchData)) {
-                throw new RuntimeException('Invalid cache file "' . self::ROUTES_CACHE_FILE . '"');
+            if (self::isRoutesCacheFileValid($dispatchData)) {
+                return new DispatcherGroupCountBased($dispatchData);
             }
-
-            return new DispatcherGroupCountBased($dispatchData);
         }
 
         $routeCollector = new RouteCollector(
@@ -191,4 +190,19 @@ class Routing
         $controller = $container->get($controllerName);
         $controller($request, $vars);
     }
+
+    /**
+     * @param mixed $dispatchData
+     *
+     * @psalm-assert-if-true array[] $dispatchData
+     */
+    private static function isRoutesCacheFileValid($dispatchData): bool
+    {
+        return is_array($dispatchData)
+            && isset($dispatchData[0], $dispatchData[1])
+            && is_array($dispatchData[0]) && is_array($dispatchData[1])
+            && isset($dispatchData[0]['GET']) && is_array($dispatchData[0]['GET'])
+            && isset($dispatchData[0]['GET']['/']) && is_string($dispatchData[0]['GET']['/'])
+            && $dispatchData[0]['GET']['/'] === HomeController::class;
+    }
 }
