@@ -1,10 +1,5 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * hold PhpMyAdmin\Twig\TransformationsExtension class
- *
- * @package PhpMyAdmin\Twig
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Twig;
@@ -13,11 +8,6 @@ use PhpMyAdmin\Transformations;
 use Twig\Extension\AbstractExtension;
 use Twig\TwigFunction;
 
-/**
- * Class TransformationsExtension
- *
- * @package PhpMyAdmin\Twig
- */
 class TransformationsExtension extends AbstractExtension
 {
     /**
@@ -28,20 +18,15 @@ class TransformationsExtension extends AbstractExtension
     public function getFunctions()
     {
         $transformations = new Transformations();
+
         return [
             new TwigFunction(
                 'get_description',
-                [
-                    $transformations,
-                    'getDescription',
-                ]
+                [$transformations, 'getDescription']
             ),
             new TwigFunction(
                 'get_name',
-                [
-                    $transformations,
-                    'getName',
-                ]
+                [$transformations, 'getName']
             ),
         ];
     }
